package devmgr.api.model;

import devmgr.api.symbol.LUNMapping;

import javax.xml.bind.annotation.XmlElement;
import java.util.List;

/**
 * Created with IntelliJ IDEA.
 * User: masonb
 * Date: 11/26/13
 * Time: 3:03 PM
 * To change this template use File | Settings | File Templates.
 */
public interface MappableObject extends Identifiable {

    /**
     * The underlying volume type of the MappableObject
     * @return
     */
    public ObjectType getObjectType();

    /**
     * Returns the Id for the object
     * @return
     */
    public String getId();
    /**
     *  The world-wide name of the volume.
     */
    public String getWwn();

    /**
     *  The user-assigned label of the volume.
     */
    public String getName();

    /**
     * The storage capacity of the volume.
     */
    public Long getTotalSizeInBytes();

    /**
     * The set of Host-to-VolumeEx LUN number mappings.
     */
    public List<LUNMapping> getListOfMappings();

    public void setMappings(List<LUNMapping> mappings);
    /**
     * Set to "true" when the volume has a valid mapping.
     */
    @XmlElement(nillable=false,required=true)
    public boolean isMapped();

    /**
     *   The reference value of the controller that currently owns (i.e. manages)
     * the volume. In non-Auto VolumeEx Transfer (non-AVT) mode, host I/O access to the blocks in this
     * volume is permitted only through the controller that is the current owner. In AVT mode, an
     * I/O access to the controller that is not the current owner causes it to automatically become
     * the current owner.
     */
    public String getCurrentControllerId() ;

    /**
     * The identifier of the controller that is the preferred owner of the
     * volume. The preferred owner is tracked independent of the current owner, since the current owner
     * may be switched dynamically as a result of host-based multi-path transitions. Later, when the
     * error conditions that cause a multi-path transition have been corrected it is still possible
     * to determine the preferred owner and switch ownership back to it.
     */
    public String getPreferredControllerId() ;

}
