package devmgr.api.model;

import io.swagger.annotations.ApiModelProperty;
import devmgr.api.symbol.*;

import javax.xml.bind.annotation.XmlRootElement;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by masonb on 1/7/14.
 */
@XmlRootElement
public class VolumeGroupEx extends VolumeGroup{
    private long usedSpace;
    private long totalRaidedSpace;
    private List<FreeExtent> extents=new ArrayList<>();
    private long largestFreeExtentSize;
    private VolumeStatus raidStatus=VolumeStatus.optimal;

    /**
     * Free space remaining on the VolumeGroup in bytes.
     * @return
     */
    public long getFreeSpace() {
        return freeSpace;
    }

    public void setFreeSpace(long freeSpace) {
        this.freeSpace = freeSpace;
    }

    private long freeSpace;

    @ApiModelProperty("True if the RAID Level is defined as raidDiskPool.")
    public boolean isDiskPool(){
        return RAIDLevel.raidDiskPool.equals(getRaidLevel());
    }

    @ApiModelProperty("Defines the physical interface type of the underlying drives.")
    public PhysicalDriveType getDrivePhysicalType() {
        return drivePhysicalType;
    }

    public void setDrivePhysicalType(PhysicalDriveType drivePhysicalType) {
        this.drivePhysicalType = drivePhysicalType;
    }

    private PhysicalDriveType drivePhysicalType;

    @ApiModelProperty("Defines whether is an SSD or a spinning drive.")
    public DriveMediaType getDriveMediaType() {
        return driveMediaType;
    }

    public void setDriveMediaType(DriveMediaType driveMediaType) {
        this.driveMediaType = driveMediaType;
    }

    private DriveMediaType driveMediaType;

    /**
     * Gets the list of free extents for the group or pool
     * @return
     */
    public List<FreeExtent> getExtents() {
        return extents;
    }

    public void setExtents(List<FreeExtent> extents) {
        this.extents = extents;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof VolumeGroupEx)) {
            return false;
        }

        VolumeGroupEx that = (VolumeGroupEx) o;

        if (getVolumeGroupRef() != null ? !getVolumeGroupRef().equals(that.getVolumeGroupRef()) : that.getVolumeGroupRef() != null) {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode() {
        return getVolumeGroupRef() != null ? getVolumeGroupRef().hashCode() : 0;
    }

    /**
     * The VolumeGroup id.
     * @return
     */
    public String getId(){
        return getVolumeGroupRef();
    }

    public VolumeGroupEx() {
    }

    /**
     * Used space in bytes.
     * @return
     */
    public long getUsedSpace() {
        return usedSpace;
    }

    public void setUsedSpace(long usedSpace) {
        this.usedSpace = usedSpace;
    }

    /**
     * Capacity of the VolumeGroup.
     * @return
     */
    @ApiModelProperty("Raw capacity of the volumeGroup")
    public long getTotalRaidedSpace() {
        return totalRaidedSpace;
    }

    public void setTotalRaidedSpace(long totalRaidedSpace) {
        this.totalRaidedSpace = totalRaidedSpace;
    }

    public void setLargestFreeExtentSize(long largestFreeExtentSize) {
        this.largestFreeExtentSize = largestFreeExtentSize;
    }


    @ApiModelProperty("The spindle speed of the drives composing the pool (RPM)")
    @Override
    public int getSpindleSpeed() {
        return super.getSpindleSpeed();
    }

    /**
     * Indicates the raw size of the largest free extent.  This is the largest size that can be used for a volume
     * @return
     */
    public long getLargestFreeExtentSize() {
        return largestFreeExtentSize;
    }

    /**
     * The "worst" status of any volume in the group
     * @return
     */
    @ApiModelProperty(value = "The raid status reflects the worst case raid level of any volume on the group")
    public VolumeStatus getRaidStatus() {
        return raidStatus;
    }

    public void setRaidStatus(VolumeStatus raidStatus) {
        this.raidStatus = raidStatus;
    }

    /**
     * Retrieve the normalized spindle speed of the pool. (Normalized spindle speeds are standardized norms (e.g., 5400, 7200, etc.) that are used for spindle speed matching, even though actual spindle speeds may be within a designated delta of the normalized speed.)
     *
     */
    @ApiModelProperty("The normalized spindle speed of the drives composing the pool. Ex: 7200, 5400, 15000. If drives have mismatched spindle speeds, this value may not be accurate.")
    public DriveSpindleSpeed getNormalizedSpindleSpeed() {
        return normalizedSpindleSpeed;
    }

    public void setNormalizedSpindleSpeed(DriveSpindleSpeed normalizedSpindleSpeed) {
        this.normalizedSpindleSpeed = normalizedSpindleSpeed;
    }

    private DriveSpindleSpeed normalizedSpindleSpeed;
}
