package devmgr.api.rpc;

import java.net.InetAddress;

import devmgr.api.runtime.XdrMessage;

/**
 * This class implements a UDP message bundle.  It contains both
 * an XDR IOV-based message buffer, plus addressing information
 * needed by underlying UDP channel logic for sending/receiving.
 */
public class UDPMessageBundle
{
    private XdrMessage m_Msg = null;
    private InetAddress m_IpAddr = null;
    private int m_Port = 0;

    /**
     * Constructor that allows all internal values to be set.
     * @param msg Message.
     * @param ipAddr Remote system's IP address.
     * @param port Remote side's port number.
     */
    public UDPMessageBundle(XdrMessage msg, InetAddress ipAddr, int port)
    {
        m_Msg = msg;
        m_IpAddr = ipAddr;
        m_Port = port;
        return;
    }

    /**
     * Returns the remote system IP address for the given message.
     * @return The remote system's IP address.
     */
    public InetAddress getAddress()
    {
        return m_IpAddr;
    }

    /**
     * Returns the remote port number for the given message.
     * @return The remote client's protocol port number.
     */
    public int getPort()
    {
        return m_Port;
    }

    /**
     * Returns the message associated with this bundled object.
     * @return The message data.
     */
    public XdrMessage getMsg()
    {
        return m_Msg;
    }
}
