package devmgr.api.runtime;

@SuppressWarnings("serial")
public class DecodeException
extends Exception
{
    public DecodeException(String msg)
    {
        super(msg);
    }
    
    /**
     * Construct a new DecodeException, referencing an original cause.
     * @param msg Message for the exception.
     * @param original Original exception that caused the problem.
     */
    private DecodeException(String msg, Exception original)
    {
        super(msg, original);
    }
    
    /**
     * Build a new exception to be thrown.
     * @param fmt Format string for message construction.
     * @param args Format arguments.
     * @return A DecodeException object to be thrown.
     */
    public static DecodeException build(String fmt, Object... args)
    {
        String msg = String.format(fmt, args);
        return new DecodeException(msg);
    }
    
    /**
     * Build an exception to be thrown, referencing the specified 
     * original as its cause.
     * @param original Original exception that caused the problem.
     * @param fmt Format string for message construction.
     * @param args Format arguments.
     * @return A DecodeException object to be thrown.
     */
    public static DecodeException build(Exception original, 
                                        String fmt, Object... args)
    {
        String msg = String.format(fmt, args);
        return new DecodeException(msg, original);
    }
}