package devmgr.api.security;
/*******************************************************************************
 * Copyright 2008-2012 NetApp, Inc. All Rights Reserved.                    *
 *                                                                             *
 * This file is confidential and a trade secret of NetApp, Inc.                *
 * The receipt of or possession of this file does not convey any rights to     *
 * reproduce or disclose its contents or to manufacture, use, or sell anything *
 * it may describe, in whole, or in part, without the specific written consent *
 * of NetApp, Inc.                                                             *
 ******************************************************************************/

/*******************************************************
 *
 * CONTACTS:
 * Originator:   Duane Loewen
 *******************************************************/

import devmgr.api.symbol.SAIdentifier;
import devmgr.api.symbolutils.ByteUtils;

import javax.crypto.Cipher;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import java.io.UnsupportedEncodingException;
import java.security.GeneralSecurityException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.Arrays;

import java.io.UnsupportedEncodingException;
import java.security.GeneralSecurityException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

import javax.crypto.Cipher;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;

import java.util.Arrays;

/**
 * Security related utility methods which are specific to NetApp, Inc. storage array.
 * <P>
 *
 * NOTES/ASSUMPTIONS: <BR>
 * None.
 * <P>
 *
 * REFERENCE: <BR>
 * <a href="https://agile.lsi.com/
 * Agile/PCMServlet?module=ItemHandler&requestUrl=module%3DItemHandler%26opcode%3D
 * displayObject%26classid%3D9000%26objid%3D158673076%26tabid%3D11%26">FAM - 35598-00 revision
 *  A.2 </a><br>
 * FFD - 34200-00
 * ER_ViewOnlyPasswordManagementA4_CB.pdf : 53791-00
 * DA_ViewOnlyPasswordManagementA4_CB.pdf : 53887-00
 * UX-Dual Password UX design document : <a href=http://sharepoint.corp.netapp.com/sites/eng/
 * storsys/CFW/main/Boxcars/OCR_Galena/Lists/TeamDiscussion UX Design Specification </a>
 */
public final class SymbolSecurity
{

    /**
     * Encrypt the pass phrase. The key encryption key and the pass phrase are hashed using SHA-256.
     * The hashed pass phrase is wrapped using AES wrap with the hashed key.
     * <P>
     * NOTES/ASSUMPTIONS: <BR>
     * None.
     *
     * @param passPhrase The pass phrase to encrypt.
     * @param storageArrayPassword The user password of the storage array.
     * @param saIndentifier The storage array ID.
     * @return The wrapped pass phrase.
     * @throws java.io.UnsupportedEncodingException if the UTF-16BE encoding doesn't exist in the JRE.
     * @throws java.security.GeneralSecurityException if the cipher cannot be init'ed or if an error occurs
     *         wrapping the passphrase.
     */
    public static byte[] encryptFDEPassPhrase(String passPhrase, String storageArrayPassword,
                                              SAIdentifier saIndentifier) throws GeneralSecurityException, UnsupportedEncodingException
    {
        MessageDigest sha256;
        byte[] hashedKeyEncryptionKey;
        byte[] keyEncryptionKey;
        SecretKey passPhraseSecretKey;
        SecretKey keyEncryptionKeySecretKey;
        byte[] hashedPassPhrase;
        Cipher cipher;
        byte[] hashedKeyEncryptionKey128;

        sha256 = MessageDigest.getInstance("SHA-256");
        //The key encryption key is the array password if there is one; otherwise use the SA ID.

        keyEncryptionKey = storageArrayPassword != null && storageArrayPassword.length() > 0 ?
                storageArrayPassword.getBytes("UTF-16BE") : ByteUtils.hexStringToByteArray(saIndentifier.getWorldWideName());

        //Hash the key encryption key with SHA-256.
        hashedKeyEncryptionKey = sha256.digest(keyEncryptionKey);
        hashedKeyEncryptionKey128 = new byte[16];
        //Truncate to the first 128 bits.
        System.arraycopy(hashedKeyEncryptionKey, 0, hashedKeyEncryptionKey128, 0, 16);
        //Hash the pass phrase with SHA-256.
        hashedPassPhrase = sha256.digest(passPhrase.getBytes("UTF-8"));

        // Create the secret key out of the hashed pass phrase that Java needs for wrapping.
        passPhraseSecretKey = new SecretKeySpec(hashedPassPhrase, "AES");
        // Create the secret key out of the hashed password or SA ID that Java needs for wrapping.
        keyEncryptionKeySecretKey = new SecretKeySpec(hashedKeyEncryptionKey128, "AES");

        // Get an AES key wrap cipher.
        cipher = Cipher.getInstance("AESWrap");
        // Initialize with the key encryption key.
        cipher.init(Cipher.WRAP_MODE, keyEncryptionKeySecretKey);
        // Wrap the pass phrase.
        return cipher.wrap(passPhraseSecretKey);
    }

    /**
     * Validate the secure message with the given digest and salt.
     * The message digest is prepared by prefixing the salt to the beginning of the password.
     * <P>
     * NOTES/ASSUMPTIONS: <BR>
     * None
     * <P>
     * @param secureMessage secure message which needs to be validated.
     * @param salt Randomly generated salt of 8 bytes length
     * @param digest Message digest
     * @return true for a valid secure message or else false.
     * @throws java.security.NoSuchAlgorithmException
     */
    public static boolean validateSecureMessage(String secureMessage, byte[] salt, byte[] digest)
            throws NoSuchAlgorithmException
    {
        MessageDigest sha = MessageDigest.getInstance("SHA");
        sha.update(salt, 0, 8);
        byte[] bytes ;
        try {
            bytes = secureMessage.getBytes("UTF-16BE");
        } catch (UnsupportedEncodingException e) {
            bytes = secureMessage.getBytes();
        }
        sha.update(bytes);
        byte[] messageDigest = sha.digest();
        return Arrays.equals(messageDigest, digest);
    }
}
