package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used to convey information about supported firmware levels that can be used to downgrade the current storage array firmware. When checking to see if it is acceptable to downgrade from the current firmware version to an older version, the controller's current firmware should be interrogated to obtain its array of CompatibleFirmware elements. All elements of the array should be checked, from beginning to end, for entries that match the version to be downloaded. As the array is searched, a cumulative ALLOWED flag should be updated each time an array element is found that matches the firmware to be downloaded. The "allowed" field of the matching element should be used to update the cumulative ALLOWED flag (the flag should be initialized to FALSE prior to starting the search). Consequently, the last matching element of the array determines the outcome of the test. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(295)
public class CompatibleFirmware implements Serializable {
	public CompatibleFirmware() {
	}

	/** A firmware package version identifier, which may or may not contain bytes with a value of FW_VERSION_WILDCARD. */
	@io.swagger.annotations.ApiModelProperty(value ="A firmware package version identifier, which may or may not contain bytes with a value of FW_VERSION_WILDCARD." , required = true)
	@XmlElement(required = true)
	private String fwVersion;

	/** @return A firmware package version identifier, which may or may not contain bytes with a value of FW_VERSION_WILDCARD. */
	public String getFwVersion() {
		return this.fwVersion;
	}
	/** @param x A firmware package version identifier, which may or may not contain bytes with a value of FW_VERSION_WILDCARD. */
	public void setFwVersion(String x) {
		this.fwVersion = x;
	}

	/** A true value indicates that any firmware version that matches the one specified in this structure is compatible with the currently-installed storage array firmware. A false value indicates that matching firmware versions are NOT compatible. */
	@io.swagger.annotations.ApiModelProperty(value ="A true value indicates that any firmware version that matches the one specified in this structure is compatible with the currently-installed storage array firmware. A false value indicates that matching firmware versions are NOT compatible." , required = true)
	@XmlElement(required = true)
	private boolean compatible;

	/** @return A true value indicates that any firmware version that matches the one specified in this structure is compatible with the currently-installed storage array firmware. A false value indicates that matching firmware versions are NOT compatible. */
	public boolean isCompatible() {
		return this.compatible;
	}
	/** @param x A true value indicates that any firmware version that matches the one specified in this structure is compatible with the currently-installed storage array firmware. A false value indicates that matching firmware versions are NOT compatible. */
	public void setCompatible(boolean x) {
		this.compatible = x;
	}
}
