package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This union data type contains information about an encrypted (new) password. It contains all of the information needed to decrypt the information, except for the (old) password that was used to encrypt the data. It is assumed that both sides, namely client and controller, know the old password and can use it to encrypt and decrypt data. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(611)
public class EncryptedPassword implements Serializable {
	public EncryptedPassword() {
	}

	/** This enumeration object is used to identify the type of encryption used for a particular operation or object. */
	@io.swagger.annotations.ApiModelProperty(value ="This enumeration object is used to identify the type of encryption used for a particular operation or object." , required = true)
	@XmlElement(required = true)
	private EncryptionType type = EncryptionType.__UNDEFINED;

	/** @return This enumeration object is used to identify the type of encryption used for a particular operation or object. */
	public EncryptionType getType() {
		return this.type;
	}
	/** @param x This enumeration object is used to identify the type of encryption used for a particular operation or object. */
	public void setType(EncryptionType x) {
		this.type = x;
	}

	/** The PKCS #5 data associated with the encrypted password. This field is valid only if the encryption type is ENCRYPT_PKCS5_SHA1_DES. */
	@io.swagger.annotations.ApiModelProperty(value ="The PKCS #5 data associated with the encrypted password. This field is valid only if the encryption type is ENCRYPT_PKCS5_SHA1_DES." , required = false)
	@XmlElement(required = false)
	private PKCS5EncryptionData pkcs5Data;

	/** @return The PKCS #5 data associated with the encrypted password. This field is valid only if the encryption type is ENCRYPT_PKCS5_SHA1_DES. */
	public PKCS5EncryptionData getPkcs5Data() {
		return this.pkcs5Data;
	}
	/** @param x The PKCS #5 data associated with the encrypted password. This field is valid only if the encryption type is ENCRYPT_PKCS5_SHA1_DES. */
	public void setPkcs5Data(PKCS5EncryptionData x) {
		this.pkcs5Data = x;
	}

	/** The PKCS#5 data associated with an AES encrypted password. This field is valid only if the encryption type is ENCRYPT_PKCS5_SHA2_AES. */
	@io.swagger.annotations.ApiModelProperty(value ="The PKCS#5 data associated with an AES encrypted password. This field is valid only if the encryption type is ENCRYPT_PKCS5_SHA2_AES." , required = false)
	@XmlElement(required = false)
	private PKCS5EncryptionData pkcs5AesData;

	/** @return The PKCS#5 data associated with an AES encrypted password. This field is valid only if the encryption type is ENCRYPT_PKCS5_SHA2_AES. */
	public PKCS5EncryptionData getPkcs5AesData() {
		return this.pkcs5AesData;
	}
	/** @param x The PKCS#5 data associated with an AES encrypted password. This field is valid only if the encryption type is ENCRYPT_PKCS5_SHA2_AES. */
	public void setPkcs5AesData(PKCS5EncryptionData x) {
		this.pkcs5AesData = x;
	}
}
