package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** The InfiniBand statistical data that is relative to a pre-set baseline-relative counters(Rel). The relative counters are the diff between the value of the raw counters at the current time and the value of the counters at the time a baseline was set via setIbStatisticsBaseline(). */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(873)
public class EnhancedIbBaselinedStatistics implements Serializable {
	public EnhancedIbBaselinedStatistics() {
	}

	/** The time at which the baseline was established. */
	@io.swagger.annotations.ApiModelProperty(value ="The time at which the baseline was established." , required = true)
	@XmlElement(required = true)
	private StatisticalTimeData timeData;

	/** @return The time at which the baseline was established. */
	public StatisticalTimeData getTimeData() {
		return this.timeData;
	}
	/** @param x The time at which the baseline was established. */
	public void setTimeData(StatisticalTimeData x) {
		this.timeData = x;
	}

	/** Contains "raw" IB host interface statistics. (1) Note that these raw values are reset to zero on a controller reboot so the counters will contain values accumulated since the last controller reboot. The one exception to this rule is when the Infiniband (IB) subnet manager running in the IB fabric resets a counter, usually as a result of a manual command issued from a host. (2) Note that the raw counters may reach a hardware limited maximum value in which case they will not accumulate any more until reset by the subnet manager or if the controller reboots. If the counter reaches its maximum value, the StatisticQualifier element for the statistic will indicate STAT_INVALID_STUCK and the value will reflect the max value. (3) Note that raw statistics that are not supported by that particular type of IB hardware will return a qualifier of STAT_NOT SUPPORTED. */
	@io.swagger.annotations.ApiModelProperty(value ="Contains \"raw\" IB host interface statistics. (1) Note that these raw values are reset to zero on a controller reboot so the counters will contain values accumulated since the last controller reboot. The one exception to this rule is when the Infiniband (IB) subnet manager running in the IB fabric resets a counter, usually as a result of a manual command issued from a host. (2) Note that the raw counters may reach a hardware limited maximum value in which case they will not accumulate any more until reset by the subnet manager or if the controller reboots. If the counter reaches its maximum value, the StatisticQualifier element for the statistic will indicate STAT_INVALID_STUCK and the value will reflect the max value. (3) Note that raw statistics that are not supported by that particular type of IB hardware will return a qualifier of STAT_NOT SUPPORTED." , required = true)
	@XmlElement(required = true)
	private EnhancedIbInterfaceStatistics[] ibInterfaceStatisticsRaw;

	/** @return Contains "raw" IB host interface statistics. (1) Note that these raw values are reset to zero on a controller reboot so the counters will contain values accumulated since the last controller reboot. The one exception to this rule is when the Infiniband (IB) subnet manager running in the IB fabric resets a counter, usually as a result of a manual command issued from a host. (2) Note that the raw counters may reach a hardware limited maximum value in which case they will not accumulate any more until reset by the subnet manager or if the controller reboots. If the counter reaches its maximum value, the StatisticQualifier element for the statistic will indicate STAT_INVALID_STUCK and the value will reflect the max value. (3) Note that raw statistics that are not supported by that particular type of IB hardware will return a qualifier of STAT_NOT SUPPORTED. */
	public EnhancedIbInterfaceStatistics[] getIbInterfaceStatisticsRaw() {
		return this.ibInterfaceStatisticsRaw;
	}
	/** @param x Contains "raw" IB host interface statistics. (1) Note that these raw values are reset to zero on a controller reboot so the counters will contain values accumulated since the last controller reboot. The one exception to this rule is when the Infiniband (IB) subnet manager running in the IB fabric resets a counter, usually as a result of a manual command issued from a host. (2) Note that the raw counters may reach a hardware limited maximum value in which case they will not accumulate any more until reset by the subnet manager or if the controller reboots. If the counter reaches its maximum value, the StatisticQualifier element for the statistic will indicate STAT_INVALID_STUCK and the value will reflect the max value. (3) Note that raw statistics that are not supported by that particular type of IB hardware will return a qualifier of STAT_NOT SUPPORTED. */
	public void setIbInterfaceStatisticsRaw(EnhancedIbInterfaceStatistics[] x) {
		this.ibInterfaceStatisticsRaw = x;
	}

	/** Contains "rel" IB host interface statistics. "Rel" is the difference between the raw counters (see IbInterfaceStatisticsRaw) and the value of the counters at the time setIserStatisticsBaseline() or setIbStatisticsBaseline() was invoked. (1) A controller reboot sets the baseline timestamp for counters for that controller to the time of the (re)boot with counter values all set to zero. (2) The subnet manager resetting a counter may cause the "rel" difference to be negative, in which case the counter's associated "value" attribute will be negative and the StatisticQualifier element will indicate STAT_INVALID_EXTERNAL_RESET. (3) Note that if the associated raw counter is set to STAT_INVALID_STUCK then the rel counter will also be set to STAT_INVALID_STUCK. (4) If the associated raw counter is set to STAT_NOT_SUPPORTED then the rel counter will be set to STAT_NOT_SUPPORTED. */
	@io.swagger.annotations.ApiModelProperty(value ="Contains \"rel\" IB host interface statistics. \"Rel\" is the difference between the raw counters (see IbInterfaceStatisticsRaw) and the value of the counters at the time setIserStatisticsBaseline() or setIbStatisticsBaseline() was invoked. (1) A controller reboot sets the baseline timestamp for counters for that controller to the time of the (re)boot with counter values all set to zero. (2) The subnet manager resetting a counter may cause the \"rel\" difference to be negative, in which case the counter's associated \"value\" attribute will be negative and the StatisticQualifier element will indicate STAT_INVALID_EXTERNAL_RESET. (3) Note that if the associated raw counter is set to STAT_INVALID_STUCK then the rel counter will also be set to STAT_INVALID_STUCK. (4) If the associated raw counter is set to STAT_NOT_SUPPORTED then the rel counter will be set to STAT_NOT_SUPPORTED." , required = true)
	@XmlElement(required = true)
	private EnhancedIbInterfaceStatistics[] ibInterfaceStatisticsRel;

	/** @return Contains "rel" IB host interface statistics. "Rel" is the difference between the raw counters (see IbInterfaceStatisticsRaw) and the value of the counters at the time setIserStatisticsBaseline() or setIbStatisticsBaseline() was invoked. (1) A controller reboot sets the baseline timestamp for counters for that controller to the time of the (re)boot with counter values all set to zero. (2) The subnet manager resetting a counter may cause the "rel" difference to be negative, in which case the counter's associated "value" attribute will be negative and the StatisticQualifier element will indicate STAT_INVALID_EXTERNAL_RESET. (3) Note that if the associated raw counter is set to STAT_INVALID_STUCK then the rel counter will also be set to STAT_INVALID_STUCK. (4) If the associated raw counter is set to STAT_NOT_SUPPORTED then the rel counter will be set to STAT_NOT_SUPPORTED. */
	public EnhancedIbInterfaceStatistics[] getIbInterfaceStatisticsRel() {
		return this.ibInterfaceStatisticsRel;
	}
	/** @param x Contains "rel" IB host interface statistics. "Rel" is the difference between the raw counters (see IbInterfaceStatisticsRaw) and the value of the counters at the time setIserStatisticsBaseline() or setIbStatisticsBaseline() was invoked. (1) A controller reboot sets the baseline timestamp for counters for that controller to the time of the (re)boot with counter values all set to zero. (2) The subnet manager resetting a counter may cause the "rel" difference to be negative, in which case the counter's associated "value" attribute will be negative and the StatisticQualifier element will indicate STAT_INVALID_EXTERNAL_RESET. (3) Note that if the associated raw counter is set to STAT_INVALID_STUCK then the rel counter will also be set to STAT_INVALID_STUCK. (4) If the associated raw counter is set to STAT_NOT_SUPPORTED then the rel counter will be set to STAT_NOT_SUPPORTED. */
	public void setIbInterfaceStatisticsRel(EnhancedIbInterfaceStatistics[] x) {
		this.ibInterfaceStatisticsRel = x;
	}
}
