package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used with the setEthernetInterfaceProperties procedure. It indicates what properties the caller wants to set and the values for those properties. To support setting a subset of these properties, all of the fields are variable-length arrays of maximum size one; If the caller does not want to set a property, the corresponding length indicator should be zero; otherwise the length indicator is one, and the single element is the new value of the property. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(767)
public class EthernetInterfaceChangeableProperties implements Serializable {
	public EthernetInterfaceChangeableProperties() {
	}

	/** Name of Ethernet port, as reported by bootWare. Note that this field is targeted for deletion in SYMbol rev 85b. */
	@io.swagger.annotations.ApiModelProperty(value ="Name of Ethernet port, as reported by bootWare. Note that this field is targeted for deletion in SYMbol rev 85b." , required = true)
	@XmlElement(required = true)
	private String[] interfaceName;

	/** @return Name of Ethernet port, as reported by bootWare. Note that this field is targeted for deletion in SYMbol rev 85b. */
	public String[] getInterfaceName() {
		return this.interfaceName;
	}
	/** @param x Name of Ethernet port, as reported by bootWare. Note that this field is targeted for deletion in SYMbol rev 85b. */
	public void setInterfaceName(String[] x) {
		this.interfaceName = x;
	}

	/** True if IPV4 is to be enabled for this interface; otherwise false. */
	@io.swagger.annotations.ApiModelProperty(value ="True if IPV4 is to be enabled for this interface; otherwise false." , required = true)
	@XmlElement(required = true)
	private boolean[] ipv4Enabled;

	/** @return True if IPV4 is to be enabled for this interface; otherwise false. */
	public boolean[] getIpv4Enabled() {
		return this.ipv4Enabled;
	}
	/** @param x True if IPV4 is to be enabled for this interface; otherwise false. */
	public void setIpv4Enabled(boolean[] x) {
		this.ipv4Enabled = x;
	}

	/** The IPV4 address for the interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The IPV4 address for the interface." , required = true)
	@XmlElement(required = true)
	private String[] ipv4Address;

	/** @return The IPV4 address for the interface. */
	public String[] getIpv4Address() {
		return this.ipv4Address;
	}
	/** @param x The IPV4 address for the interface. */
	public void setIpv4Address(String[] x) {
		this.ipv4Address = x;
	}

	/** The IPV4 subnet mask for the interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The IPV4 subnet mask for the interface." , required = true)
	@XmlElement(required = true)
	private String[] ipv4SubnetMask;

	/** @return The IPV4 subnet mask for the interface. */
	public String[] getIpv4SubnetMask() {
		return this.ipv4SubnetMask;
	}
	/** @param x The IPV4 subnet mask for the interface. */
	public void setIpv4SubnetMask(String[] x) {
		this.ipv4SubnetMask = x;
	}

	/** Setting that determines how the IPV4 address is configured. */
	@io.swagger.annotations.ApiModelProperty(value ="Setting that determines how the IPV4 address is configured." , required = true)
	@XmlElement(required = true)
	private IpV4ConfigMethod[] ipv4AddressConfigMethod;

	/** @return Setting that determines how the IPV4 address is configured. */
	public IpV4ConfigMethod[] getIpv4AddressConfigMethod() {
		return this.ipv4AddressConfigMethod;
	}
	/** @param x Setting that determines how the IPV4 address is configured. */
	public void setIpv4AddressConfigMethod(IpV4ConfigMethod[] x) {
		this.ipv4AddressConfigMethod = x;
	}

	/** True if IPV6 is to be enabled for this interface; otherwise false. */
	@io.swagger.annotations.ApiModelProperty(value ="True if IPV6 is to be enabled for this interface; otherwise false." , required = true)
	@XmlElement(required = true)
	private boolean[] ipv6Enabled;

	/** @return True if IPV6 is to be enabled for this interface; otherwise false. */
	public boolean[] getIpv6Enabled() {
		return this.ipv6Enabled;
	}
	/** @param x True if IPV6 is to be enabled for this interface; otherwise false. */
	public void setIpv6Enabled(boolean[] x) {
		this.ipv6Enabled = x;
	}

	/** The IPV6 local address for the interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The IPV6 local address for the interface." , required = true)
	@XmlElement(required = true)
	private IpV6AddressData[] ipv6LocalAddress;

	/** @return The IPV6 local address for the interface. */
	public IpV6AddressData[] getIpv6LocalAddress() {
		return this.ipv6LocalAddress;
	}
	/** @param x The IPV6 local address for the interface. */
	public void setIpv6LocalAddress(IpV6AddressData[] x) {
		this.ipv6LocalAddress = x;
	}

	/** The IPV6 static routable address for the interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The IPV6 static routable address for the interface." , required = true)
	@XmlElement(required = true)
	private IpV6AddressData[] ipv6PortStaticRoutableAddress;

	/** @return The IPV6 static routable address for the interface. */
	public IpV6AddressData[] getIpv6PortStaticRoutableAddress() {
		return this.ipv6PortStaticRoutableAddress;
	}
	/** @param x The IPV6 static routable address for the interface. */
	public void setIpv6PortStaticRoutableAddress(IpV6AddressData[] x) {
		this.ipv6PortStaticRoutableAddress = x;
	}

	/** The method by which the IPV6 address information is configured for the interface. */
	@io.swagger.annotations.ApiModelProperty(value ="The method by which the IPV6 address information is configured for the interface." , required = true)
	@XmlElement(required = true)
	private IpV6ConfigMethod[] ipv6AddressConfigMethod;

	/** @return The method by which the IPV6 address information is configured for the interface. */
	public IpV6ConfigMethod[] getIpv6AddressConfigMethod() {
		return this.ipv6AddressConfigMethod;
	}
	/** @param x The method by which the IPV6 address information is configured for the interface. */
	public void setIpv6AddressConfigMethod(IpV6ConfigMethod[] x) {
		this.ipv6AddressConfigMethod = x;
	}

	/** Determines the speed and duplex for interface. */
	@io.swagger.annotations.ApiModelProperty(value ="Determines the speed and duplex for interface." , required = true)
	@XmlElement(required = true)
	private EthernetSpeedSetting[] configuredSpeedSetting;

	/** @return Determines the speed and duplex for interface. */
	public EthernetSpeedSetting[] getConfiguredSpeedSetting() {
		return this.configuredSpeedSetting;
	}
	/** @param x Determines the speed and duplex for interface. */
	public void setConfiguredSpeedSetting(EthernetSpeedSetting[] x) {
		this.configuredSpeedSetting = x;
	}
}
