package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used as an argument when downloading a new firmware or NVSRAM image to a controller. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(454)
public class FirmwareUpdateDescriptor implements Serializable {
	public FirmwareUpdateDescriptor() {
	}

	/** A raw byte array that contains a segment, or chunk, of the firmware (or NVSRAM) image being downloaded to a controller. For firmware downloads, iterative operations are supported, where the overall firmware image can be iteratively transferred to the controller in multiple chunks. For NVSRAM downloads, however, the entire NVSRAM image must be provided in one call. */
	@io.swagger.annotations.ApiModelProperty(value ="A raw byte array that contains a segment, or chunk, of the firmware (or NVSRAM) image being downloaded to a controller. For firmware downloads, iterative operations are supported, where the overall firmware image can be iteratively transferred to the controller in multiple chunks. For NVSRAM downloads, however, the entire NVSRAM image must be provided in one call." , required = true)
	@XmlElement(required = true)
	private String firmwareChunkImage;

	/** @return A raw byte array that contains a segment, or chunk, of the firmware (or NVSRAM) image being downloaded to a controller. For firmware downloads, iterative operations are supported, where the overall firmware image can be iteratively transferred to the controller in multiple chunks. For NVSRAM downloads, however, the entire NVSRAM image must be provided in one call. */
	public String getFirmwareChunkImage() {
		return this.firmwareChunkImage;
	}
	/** @param x A raw byte array that contains a segment, or chunk, of the firmware (or NVSRAM) image being downloaded to a controller. For firmware downloads, iterative operations are supported, where the overall firmware image can be iteratively transferred to the controller in multiple chunks. For NVSRAM downloads, however, the entire NVSRAM image must be provided in one call. */
	public void setFirmwareChunkImage(String x) {
		this.firmwareChunkImage = x;
	}

	/** An ASCII character string that identifies the version of the firmware or NVSRAM being downloaded. */
	@io.swagger.annotations.ApiModelProperty(value ="An ASCII character string that identifies the version of the firmware or NVSRAM being downloaded." , required = true)
	@XmlElement(required = true)
	private String firmwareVersion;

	/** @return An ASCII character string that identifies the version of the firmware or NVSRAM being downloaded. */
	public String getFirmwareVersion() {
		return this.firmwareVersion;
	}
	/** @param x An ASCII character string that identifies the version of the firmware or NVSRAM being downloaded. */
	public void setFirmwareVersion(String x) {
		this.firmwareVersion = x;
	}

	/** The offset of this chunk from the beginning of the overall image. */
	@io.swagger.annotations.ApiModelProperty(value ="The offset of this chunk from the beginning of the overall image." , required = true)
	@XmlElement(required = true)
	private int offset;

	/** @return The offset of this chunk from the beginning of the overall image. */
	public int getOffset() {
		return this.offset;
	}
	/** @param x The offset of this chunk from the beginning of the overall image. */
	public void setOffset(int x) {
		this.offset = x;
	}

	/** The total size of the overall firmware image. */
	@io.swagger.annotations.ApiModelProperty(value ="The total size of the overall firmware image." , required = true)
	@XmlElement(required = true)
	private int totalSize;

	/** @return The total size of the overall firmware image. */
	public int getTotalSize() {
		return this.totalSize;
	}
	/** @param x The total size of the overall firmware image. */
	public void setTotalSize(int x) {
		this.totalSize = x;
	}

	/** If false, activate firmware after download. If true, stage firmware for later activation. */
	@io.swagger.annotations.ApiModelProperty(value ="If false, activate firmware after download. If true, stage firmware for later activation." , required = true)
	@XmlElement(required = true)
	private boolean stagedDownload;

	/** @return If false, activate firmware after download. If true, stage firmware for later activation. */
	public boolean isStagedDownload() {
		return this.stagedDownload;
	}
	/** @param x If false, activate firmware after download. If true, stage firmware for later activation. */
	public void setStagedDownload(boolean x) {
		this.stagedDownload = x;
	}

	/** The number of files in this download stream. */
	@io.swagger.annotations.ApiModelProperty(value ="The number of files in this download stream." , required = true)
	@XmlElement(required = true)
	private int numberOfFiles;

	/** @return The number of files in this download stream. */
	public int getNumberOfFiles() {
		return this.numberOfFiles;
	}
	/** @param x The number of files in this download stream. */
	public void setNumberOfFiles(int x) {
		this.numberOfFiles = x;
	}

	/** Total size (in bytes) of all files being downloaded in this download stream. */
	@io.swagger.annotations.ApiModelProperty(value ="Total size (in bytes) of all files being downloaded in this download stream." , required = true)
	@XmlElement(required = true)
	private int sizeOfStream;

	/** @return Total size (in bytes) of all files being downloaded in this download stream. */
	public int getSizeOfStream() {
		return this.sizeOfStream;
	}
	/** @param x Total size (in bytes) of all files being downloaded in this download stream. */
	public void setSizeOfStream(int x) {
		this.sizeOfStream = x;
	}
}
