package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure contains information about connection-level settings that are subject to initiator-target negotiation. It is used in two contexts: (1) reporting controller default settings (i.e., those that are the starting point for negotiation), and (2) reporting the current active settings. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(304)
public class IscsiNegotiableConnectionSettings implements Serializable {
	public IscsiNegotiableConnectionSettings() {
	}

	/** The maximum data payload size supported for command or data PDUs able to be received on this connection. */
	@io.swagger.annotations.ApiModelProperty(value ="The maximum data payload size supported for command or data PDUs able to be received on this connection." , required = true)
	@XmlElement(required = true)
	private int maxReceiveDataSegmentLength;

	/** @return The maximum data payload size supported for command or data PDUs able to be received on this connection. */
	public int getMaxReceiveDataSegmentLength() {
		return this.maxReceiveDataSegmentLength;
	}
	/** @param x The maximum data payload size supported for command or data PDUs able to be received on this connection. */
	public void setMaxReceiveDataSegmentLength(int x) {
		this.maxReceiveDataSegmentLength = x;
	}

	/** The iSCSI header digest scheme in use within this connection. This field is an array of at most two elements so that, when reporting default settings, both primary and secondary methods can be reported, which are at array indexes 0 and 1 respectively. When used to report current settings, the array is sized at one. */
	@io.swagger.annotations.ApiModelProperty(value ="The iSCSI header digest scheme in use within this connection. This field is an array of at most two elements so that, when reporting default settings, both primary and secondary methods can be reported, which are at array indexes 0 and 1 respectively. When used to report current settings, the array is sized at one." , required = true)
	@XmlElement(required = true)
	private DigestMethod[] headerDigestMethod;

	/** @return The iSCSI header digest scheme in use within this connection. This field is an array of at most two elements so that, when reporting default settings, both primary and secondary methods can be reported, which are at array indexes 0 and 1 respectively. When used to report current settings, the array is sized at one. */
	public DigestMethod[] getHeaderDigestMethod() {
		return this.headerDigestMethod;
	}
	/** @param x The iSCSI header digest scheme in use within this connection. This field is an array of at most two elements so that, when reporting default settings, both primary and secondary methods can be reported, which are at array indexes 0 and 1 respectively. When used to report current settings, the array is sized at one. */
	public void setHeaderDigestMethod(DigestMethod[] x) {
		this.headerDigestMethod = x;
	}

	/** The iSCSI data digest scheme in use within this connection. The same method is followed as for header digest in reporting default versus current settings. */
	@io.swagger.annotations.ApiModelProperty(value ="The iSCSI data digest scheme in use within this connection. The same method is followed as for header digest in reporting default versus current settings." , required = true)
	@XmlElement(required = true)
	private DigestMethod[] dataDigestMethod;

	/** @return The iSCSI data digest scheme in use within this connection. The same method is followed as for header digest in reporting default versus current settings. */
	public DigestMethod[] getDataDigestMethod() {
		return this.dataDigestMethod;
	}
	/** @param x The iSCSI data digest scheme in use within this connection. The same method is followed as for header digest in reporting default versus current settings. */
	public void setDataDigestMethod(DigestMethod[] x) {
		this.dataDigestMethod = x;
	}

	/** True if this connection is receiving markers in in its incoming data stream. */
	@io.swagger.annotations.ApiModelProperty(value ="True if this connection is receiving markers in in its incoming data stream." , required = true)
	@XmlElement(required = true)
	private boolean receivingMarkers;

	/** @return True if this connection is receiving markers in in its incoming data stream. */
	public boolean isReceivingMarkers() {
		return this.receivingMarkers;
	}
	/** @param x True if this connection is receiving markers in in its incoming data stream. */
	public void setReceivingMarkers(boolean x) {
		this.receivingMarkers = x;
	}

	/** The authentication method being used on this connection, as communicated during the login phase. The same method is followed as for header digest in reporting default versus current settings. */
	@io.swagger.annotations.ApiModelProperty(value ="The authentication method being used on this connection, as communicated during the login phase. The same method is followed as for header digest in reporting default versus current settings." , required = true)
	@XmlElement(required = true)
	private AuthenticationMethod[] authMethod;

	/** @return The authentication method being used on this connection, as communicated during the login phase. The same method is followed as for header digest in reporting default versus current settings. */
	public AuthenticationMethod[] getAuthMethod() {
		return this.authMethod;
	}
	/** @param x The authentication method being used on this connection, as communicated during the login phase. The same method is followed as for header digest in reporting default versus current settings. */
	public void setAuthMethod(AuthenticationMethod[] x) {
		this.authMethod = x;
	}
}
