package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** An enumeration used to determine the return status of a SYMbol function call. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(117)
public enum ReturnCode implements Serializable {
		/** Value when an object has not been initialized */
		uninitialized(0),
		/** The operation completed successfully. */
		ok(1),
		/** The operation cannot complete because either (1) the current state of a component does not allow the operation to be completed, (2) the operation has been disabled in NVSRAM (example, you are modifying media scan parameters when that option (offset 0x31, bit 5) is disabled), or (3) there is a problem with the storage array. Please check your storage array and its various components for possible problems and then retry the operation. */
		error(2),
		/** The operation cannot complete because a controller resource is being used by another process. If there are other array management operations in progress, wait for them to complete, and then retry the operation. If this message persists after all operations have completed, contact technical support. */
		busy(3),
		/** The operation cannot complete because of an incorrect parameter in the command sent to the controller. Please retry the operation. If this message persists, contact your Technical Support Representative. */
		illegalParam(4),
		/** An out of memory error occurred on one of the controllers in the storage array. Contact your Technical Support Representative about the memory requirements for this storage array. */
		noHeap(5),
		/** The operation cannot complete because one or more specified drives do not exist. Please specify only drives currently installed in the storage array and then retry the operation. */
		driveNotExist(6),
		/** The operation cannot complete because one or more specified drives do not have an unassigned status. Please specify only drives with an unassigned status and then retry the operation. */
		driveNotUnassigned(7),
		/** No hot spare drives were assigned. Possible causes include (1) the maximum number of hot spare drives that can be assigned automatically have already been assigned or (2) the maximum number of hot spares for the entire storage array have been assigned, (3) there are no more unassigned drives available, or (4) any remaining unassigned drives have capacities that are smaller than all other drives in the storage array. If you suspect the first cause, manually assign more hot spare drives. If you suspect the fourth cause, obtain the selected drives' capacity. */
		noSparesAssigned(8),
		/** Not all of the requested unassigned drives were assigned as hot spares. Determine which drives were assigned. Possible causes include (1) the maximum number of hot spares have been assigned or (2) some of the unassigned drives have capacities that are smaller than all other drives in the storage array. If you suspect the second cause, obtain the unassigned drives' capacity. */
		someSparesAssigned(9),
		/** The specified volume does not exist. The volume may have been deleted by a user on another management station accessing this storage array. */
		volumeNotExist(10),
		/** The operation cannot complete because a volume is performing a modification operation. Please wait until the modification completes and then retry the operation. */
		volumeReconfiguring(11),
		/** The operation cannot complete because the controllers in the storage array must be online. */
		notDualActive(12),
		/** This operation must be performed by the alternate controller. */
		tryAlternate(13),
		/** An operation is running in the background. */
		background(14),
		/** This option is currently not implemented. */
		notImplemented(15),
		/** The operation cannot complete because an application has reserved the selected volume. Please wait until the volume has been released and then retry the operation. */
		reservationConflict(16),
		/** The operation cannot complete because either the volume remains failed or has transitioned to failed. Please use the Recovery Guru to resolve the problem. */
		volumeDead(17),
		/** The operation cannot complete because of an internal target error. Please retry the operation. If this message persists, contact your Technical Support Representative. */
		internalError(18),
		/** The operation cannot complete because of a general configuration request error. Please retry the operation. If this message persists, contact your Technical Support Representative. */
		invalidRequest(19),
		/** The operation cannot complete because there is a communications failure between the controllers. Please turn the power to the controller tray off and then on and then retry the operation. If this message persists, contact your Technical Support Representative. */
		iconFailure(20),
		/** The operation cannot complete because a volume initialization is in progress. Please wait until the initialization completes and then retry the operation. */
		volumeFormatting(21),
		/** The operation cannot complete because the other controller is not present. Please insert the other controller and retry the operation. */
		altRemoved(22),
		/** The operation cannot complete because the cache between the controllers could not be synchronized. This normally occurs if the controller's alternate pair has not completed its start-of-day routine. Please wait at least two minutes and then retry the operation. If this message persists, contact your Technical Support Representative. */
		cacheSyncFailure(23),
		/** The download cannot complete because a file is not valid. Replace the file and retry the operation. */
		invalidFile(24),
		/** The modification operation cannot complete because the controller configuration area (DACStore) is too small. Contact your Technical Support Representative. */
		reconfigSmallDacstore(25),
		/** The modification operation cannot complete because of the number of drives in the volume group and the segment size of the associated volumes. Reduce the segment size of all volumes in the volume group and retry the operation. If this message persists, contact your Technical Support Representative. */
		reconfigFailure(26),
		/** Unable to read or write NVSRAM. */
		nvramError(27),
		/** There was a failure in transferring the firmware to flash memory during a download operation. Please retry the operation. */
		flashError(28),
		/** This operation cannot complete because there was a security authentication failure on a parameter in the command sent to the controller. Please retry the operation. If this message persists, contact your Technical Support Representative. */
		authFailParam(29),
		/** The operation cannot complete because you did not provide a valid administrator password. */
		authFailPassword(30),
		/** There is a memory parity error on the controller. */
		memParityError(31),
		/** The operation cannot complete because the controller specified in the request is not valid. */
		invalidControllerref(32),
		/** The operation cannot complete because the volume group specified in the request is not valid. The volume group may have been deleted or modified by a user on another management station accessing this storage array, or one or more of the following conditions are present: 1) one or more of the drives in the volume group is not security capable, 2) the volume group contains one or more snapshot copy base or repository volumes, or 3) the volume group is not in an optimal state. */
		invalidVolumegroupref(33),
		/** The operation cannot complete because the volume specified in the request is not valid. The volume may have been deleted or modified by a user on another management station accessing this storage array. */
		invalidVolumeref(34),
		/** The operation cannot complete because the drive specified in the request is not valid. The drive may have been used or modified by a user on another management station accessing this storage array. */
		invalidDriveref(35),
		/** The operation cannot complete because the free capacity specified in the request is not valid. The free capacity may have been used or modified by a user on another management station accessing this storage array. */
		invalidFreeextentref(36),
		/** The operation cannot complete because the volume group is offline. Please place the volume group online. */
		volumeOffline(37),
		/** The operation cannot complete because some volumes are not optimal. Please correct the problem causing the non-optimal volumes using the Recovery Guru and then retry the operation. */
		volumeNotOptimal(38),
		/** The operation cannot complete because state information could not be retrieved from one or more controllers in the storage array. */
		modesenseError(39),
		/** The operation cannot complete for one of the following reasons: (1) The requested segment size is not valid, (2) The requested segment size is not allowed because it is more than twice or less than half the current segment size, or (3) The requested segment size is not allowed because this volume has an odd number of segments. If case (3) applies, you may only decrease the segment size for this volume to a smaller number. */
		invalidSegmentsize(40),
		/** The operation cannot complete because the cache block size requested is not valid. */
		invalidCacheblksize(41),
		/** The operation cannot complete because the start cache flush value requested is not valid. */
		invalidFlushThreshold(42),
		/** The operation cannot complete because the stop cache flush value requested is not valid. */
		invalidFlushAmount(43),
		/** The name you have provided cannot be used. The most likely cause is that the name is already used by another volume. Please provide another name. */
		invalidLabel(44),
		/** The operation cannot complete because the cache flush modifier requested is not valid. */
		invalidCacheModifier(45),
		/** The operation cannot complete because the cache read ahead requested is not valid. */
		invalidReadahead(46),
		/** The operation cannot complete because the modification priority requested is not valid. */
		invalidReconpriority(47),
		/** The operation cannot complete because the media scan duration requested is not valid. */
		invalidScanperiod(48),
		/** The operation cannot complete because the number of trays requested has exceeded the maximum value. */
		invalidTrayposLength(49),
		/** The operation cannot complete because the requested NVSRAM region is not valid. */
		invalidRegionid(50),
		/** The operation cannot complete because the preferred loop ID requested is not valid. Please specify an ID between 0 and 127. */
		invalidFibreid(51),
		/** The operation cannot complete because the encryption routine requested is not valid. */
		invalidEncryption(52),
		/** The operation cannot complete because it is not supported on SSD cache or because of the current RAID level of the volume group. Remember that some operations cannot be performed on certain RAID levels because of redundancy or drive requirements. */
		invalidRaidlevel(53),
		/** The operation cannot complete because the number of drives selected is not valid. */
		invalidExpansionList(54),
		/** No hot spare drives were unassigned. Possible causes include (1) the drives are not hot spares, (2) the hot spares are removed, (3) the hot spares are failed, or (4) the hot spares are In Use (integrated into a volume group). Check these possible causes and then retry the operation. */
		noSparesDeassigned(55),
		/** Not all of the requested hot spare drives were unassigned. Possible causes include (1) the drives are not hot spares, (2) the hot spares are removed, (3) the hot spares are failed, or (4) the hot spares are In Use (integrated into a volume group). Check these possible causes and then retry the operation. */
		someSparesDeassigned(56),
		/** The operation cannot complete because the identifier or name you provided already exists. Please provide another identifier or name and then retry the operation. */
		partDupId(57),
		/** The operation cannot complete because the name you provided is not valid. Please provide a non-blank name and then retry the operation. */
		partLabelInvalid(58),
		/** The operation cannot complete because the host group, host, or host port you have selected no longer exists. The object may have been deleted or modified by a user on another management station accessing this storage array. Please close and re-open the dialog box to refresh the information. */
		partNodeNonexistent(59),
		/** The creation of the host port cannot complete because the host port identifier is not valid. Either the identifier is empty or has characters other than 0-9 and A-F. Please enter a valid host port identifier and then retry the operation. */
		partPortIdInvalid(60),
		/** The creation of a new volume-to-LUN mapping cannot complete because the volume you have selected no longer exists. The volume may have been deleted or modified by a user on another management station accessing this storage array. Please close and open the dialog box to refresh the information. */
		partVolumeNonexistent(61),
		/** The operation cannot complete because the logical unit number (LUN) is already in use. Please enter another LUN. */
		partLunCollision(62),
		/** The operation cannot complete because the maximum number of mappings has already been defined for this volume. The mapping may have defined by a user on another management station accessing this storage array. */
		maxVolMappingExceeded(63),
		/** The operation cannot complete because the volume-to-LUN mapping you have selected no longer exists. The mapping may have been deleted by a user on another management station accessing this storage array. Please close and re-open the dialog box to refresh the information. */
		partMappingNonexistent(64),
		/** The operation cannot complete because the host group or host has no host ports. Please define a host port for the host group or host and then retry the operation. */
		partNoHostports(65),
		/** The image was successfully transferred. */
		imageTransferred(66),
		/** The download cannot complete because a file is not valid. Replace the file and retry the operation. */
		fileTooLarge(67),
		/** A problem has occurred during the download. Please retry the operation. */
		invalidOffset(68),
		/** The download cannot complete because a file is not valid. Replace the file and retry the operation. */
		overrun(69),
		/** A problem has occurred during the download. Please retry the operation. */
		invalidChunksize(70),
		/** The download cannot complete because a file is not valid. Replace the file and retry the operation. */
		invalidTotalsize(71),
		/** The requested download cannot complete because the NVSRAM option to support this download type is disabled. Contact your Technical Support Representative. */
		downloadNotPermitted(72),
		/** A resource allocation error (unable to spawn a task) occurred on one of the controllers in the storage array. */
		spawnError(73),
		/** The operation cannot complete because the controller was unable to transfer the volumes to its alternate controller. Please check the alternate controller for problems and then retry the operation. */
		voltransferError(74),
		/** The operation cannot complete because the controller pair is in Service mode. Please set the status of the controller in Service mode to Online and then retry the operation. */
		invalidDlstate(75),
		/** The operation cannot complete because of an incorrect controller configuration. Possible causes include (1) the controller pair is in an Active/Passive mode, or (2) controller cache synchronization failed. Please change the passive controller to active and then retry the operation. If this message persists, contact your Technical Support Representative. */
		cacheconfigError(76),
		/** The operation cannot complete because a download is already in progress. Please wait for the download to complete and, if necessary, retry the operation. */
		downloadInProgress(77),
		/** The operation cannot complete because a drive in the volume group or disk pool is not optimal. Please correct the problem using the Recovery Guru and then retry the operation. */
		driveNotOptimal(78),
		/** The operation cannot complete because a drive in the volume group is removed. Please insert a drive and then retry the operation. */
		driveRemoved(79),
		/** The operation cannot complete because the selected drive is already part of the volume group. Please select another drive and retry the operation. */
		duplicateDrives(80),
		/** The operation cannot complete because the number of drives selected exceeds the maximum additional drives allowed. Please select a smaller number of drives and then retry the operation. */
		numdrivesAdditional(81),
		/** The operation cannot complete because either (1) the number of drives selected is not valid for the RAID level of the volume group or (2) the number of drives in the volume group is not valid for the proposed RAID level. */
		numdrivesGroup(82),
		/** The operation cannot complete because at least one of the drives selected has a capacity that is not large enough to hold the existing data of the volume group. Please select another drive and retry the operation. */
		driveTooSmall(83),
		/** The operation cannot complete because there is no free capacity or not enough free capacity on the volume group to accommodate the new RAID level. */
		capacityConstrained(84),
		/** The operation cannot complete because the maximum number of volumes for this storage array has been reached. */
		maxVolumesExceeded(85),
		/** The operation cannot complete because the logical unit number (LUN) is already in use by the Access Volume. Please select another LUN. */
		partIsUtmLun(86),
		/** One or more drives were assigned as hot spares. However, some of the drives do not have a capacity large enough to cover all of the drives in the storage array. If a drive fails that has a capacity larger than these hot spares drives, it will not be covered by these drives. */
		someSparesTooSmall(87),
		/** Not all of the requested drives were assigned as hot spares. In addition, one or more drives that were assigned as hot spares do not have a capacity large enough to cover all of the drives in the storage array. If a drive fails that has a capacity larger than these hot spares drives, it will not be covered by these drives. Check the hot spare coverage. You may want to unassign the smaller-capacity hot spare drives. */
		sparesSmallUnassigned(88),
		/** The volume assignment you are attempting on the host cluster (group) or host cannot occur because either (1) the maximum number of host clusters or hosts that have at least one volume assignment has been reached or (2) the feature that allows you to assign a volume to a specific host cluster or host is not enabled. */
		tooManyPartitions(89),
		/** A redundancy check is already in progress. Either a redundancy check is currently being performed or it was canceled but the time-out period (1 to 2 minutes) has not been reached. Please wait until the check has completed or timed out and then retry the operation. */
		parityScanInProgress(90),
		/** The feature enable identifier contained in the feature key file you have selected does not match the identifier for this storage array. Please select another feature key file or obtain a feature key file using the correct identifier. Determine the feature enable identifier for this storage array. */
		invalidSafeId(91),
		/** The feature key file you have selected is not valid. The security (digest) information contained in the file does not match what was expected from the controller. Please contact your Technical Support Representative. */
		invalidSafeKey(92),
		/** The premium feature you are attempting to enable with this feature key file is not supported on the current configuration of this storage array. Please determine the configuration (such as appropriate level of firmware and hardware) necessary to support this feature. Contact your Technical Support Representative if necessary. */
		invalidSafeCapability(93),
		/** The feature key file you have selected is not valid. The version information contained in the file does not match what was expected from the controller. Please contact your Technical Support Representative. */
		invalidSafeVersion(94),
		/** The operation cannot complete because the Mapping equals None parameter is not allowed on this storage array. Use the Mapping equals Default parameter instead. */
		partitionsDisabled(95),
		/** A firmware download to a drive failed. */
		driveDownloadFailed(96),
		/** A firmware download to an ESM cannot complete. If your storage array is not optimal, please correct any problems using the Recovery Guru and then retry the download operation. */
		esmDownloadFailed(97),
		/** The firmware versions on the ESM cards do not match. Please retry the download operation. */
		esmPartialUpdate(98),
		/** The operation could not complete because the NVSRAM offset 0x32 is attempting to enable a logical unit number (LUN) for an access volume that conflicts with a LUN for a volume that already exists on the storage array. If you are downloading a new NVSRAM file, you will need to obtain a new file with the offset set to a LUN that does not conflict. If you are using the script editor or CLI to set this NVSRAM offset, you must choose a different LUN that does not conflict. */
		utmConflict(99),
		/** The operation cannot complete because a volume must exist on the storage array. */
		noVolumes(100),
		/** The operation cannot complete because either there is a problem communicating with any of the drives in the storage array or there are currently no drives connected. Please correct the problem and then retry the operation. */
		authFailReadpassword(101),
		/** The operation cannot complete because the maximum number of host-groups, hosts, and host-ports have been created for this storage array. */
		partCrteFailTblFull(102),
		/** The operation cannot complete because you are attempting to modify host-dependent values for region ID 0xF1. You must change host-dependent values in one of the host index areas. */
		attemptToSetLocal(103),
		/** The operation cannot complete because the host index must be between 0 and 15. */
		invalidHostTypeIndex(104),
		/** The operation cannot complete because the volume you are trying to assign is already assigned to a host cluster (group) or host. */
		failVolumeVisible(105),
		/** The operation cannot complete because you are attempting to delete the access volume-to-LUN mapping that you are currently using to communicate with this storage array. */
		noDeleteUtmInUse(106),
		/** The operation cannot complete because the logical unit number (LUN) is not valid. */
		invalidLun(107),
		/** The operation cannot complete because the logical unit number you are attempting to map to this access volume is outside the allowable range. Please select one of the logical unit numbers (LUN) that have already been mapped to one of the other access volumes. */
		utmTooManyMaps(108),
		/** The controller diagnostics read test has failed and the controller has been placed offline. Use the Recovery Guru to replace the failed controller. For more information on the read test, refer to the online help. */
		diagReadFailure(109),
		/** The diagnostics passed, but I/Os were performed internally because the test was unable to communicate on the host/source links. */
		diagSrcLinkDown(110),
		/** Diagnostics Write test failed. The controller has been placed offline. Use the Recovery Guru to replace the faulty controller. For information on write test failures, refer to online Help. */
		diagWriteFailure(111),
		/** The controller diagnostics passed. However, the test identified an error on one or more of the loops. For more information on the loopback test, refer to the online help. */
		diagLoopbackError(112),
		/** The diagnostics operation cannot complete because the controller did not respond within the allotted time. The controller has been placed offline. Use the Recovery Guru to recover from the offline controller. */
		diagTimeout(113),
		/** The diagnostics operation cannot complete because a diagnostics operation is already in progress. */
		diagInProgress(114),
		/** The diagnostics operation cannot complete because the operation requires two online controllers. */
		diagNoAlt(115),
		/** The diagnostics operation cannot complete because of a communication error between controllers. */
		diagIconSendErr(116),
		/** The diagnostics operation cannot complete because of an internal initialization error. */
		diagInitErr(117),
		/** The diagnostics operation cannot complete because both controllers are not in the online mode. */
		diagModeErr(118),
		/** The diagnostics operation cannot complete because the controller does not support one or more selected diagnostic tests. */
		diagInvalidTestId(119),
		/** The diagnostics operation cannot complete because the controller was unable to obtain the location of the diagnostics data repository. */
		diagDriveErr(120),
		/** The diagnostics operation cannot complete because the controller was unable to obtain a mode select lock. */
		diagLockErr(121),
		/** The diagnostics operation cannot complete because a diagnostic volume cannot be created. */
		diagConfigErr(122),
		/** The diagnostics operation cannot complete because there was not enough memory available. */
		diagNoCacheMem(123),
		/** The diagnostics operation cannot complete because the operation cannot disable data transfer. */
		diagNotQuiesced(124),
		/** The diagnostics operation cannot complete because an access volume is not defined. */
		diagUtmNotEnabled(125),
		/** The controller mode switch to passive failed because the controller has Auto-Volume Transfer mode enabled. For more information about AVT, see "Learn about Auto-Volume Transfer and Multi-Path Drivers" in the Learn More section of the online help. */
		invalidModeSwitch(126),
		/** The operation cannot complete because the I/O interface specified in the request is not valid (unknown port name). */
		invalidPortname(127),
		/** The operation cannot complete because the volume has already been assigned to this host cluster (group) or host. A host cluster or host cannot have a duplicate assignment to the same volume. */
		duplicateVolMapping(128),
		/** The operation cannot complete because the maximum number of snapshot volumes have been created for this base volume. */
		maxSnapsPerBaseExceeded(129),
		/** The operation cannot complete because the maximum number of snapshot volumes have been created for this storage array. */
		maxSnapsExceeded(130),
		/** The operation cannot complete because: (1) you attempted to create a snapshot volume on: a snapshot repository volume, another snapshot volume, a mirror repository volume, or a target volume in a Volume Copy pair. (2) you attempted to create a snapshot (legacy) volume on a thin volume, (3) you cannot mix a snapshot (legacy) volume and a new snapshot volume on the same base volume, (4) the base volume is undergoing rollback, or (5) the base volume contains unreadable sectors. Check the Recovery Guru for an unreadable sectors problem and follow the recommended procedure. */
		invalidBasevol(131),
		/** The operation cannot complete because the snapshot volume's associated base volume or repository volume is missing. */
		snapNotAvailable(132),
		/** One or more of the snaps on the base being converted are not in the 'stopped' state. */
		notDisabled(133),
		/** The operation cannot complete because the Snapshot Volume Premium Feature is disabled or unauthorized. */
		snapshotFeatureDisabled(134),
		/** The operation cannot complete because the volume's associated repository volume is in an offline state. */
		repositoryOffline(135),
		/** The delete operation cannot complete because the snapshot volume's associated repository volume is currently performing a modification operation. Please wait until the modification completes and then retry the operation. */
		repositoryReconfiguring(136),
		/** The operation cannot complete because there is a rollback operation in progress. */
		rollbackInProgress(137),
		/** The operation cannot complete because the maximum number of volumes has been created on this volume group. */
		numVolumesGroup(138),
		/** The operation cannot complete because the volume on which you are attempting to perform the operation is missing. The only action that can be performed on a missing volume is deletion. */
		ghostVolume(139),
		/** The delete operation cannot complete because the snapshot volume's associated repository volume is missing. */
		repositoryMissing(140),
		/** The operation cannot complete because the name you provided for the snapshot repository volume already exists. Please provide another name and then retry the operation. */
		invalidRepositoryLabel(141),
		/** The operation cannot complete because the name you provided for the snapshot volume already exists. Please provide another name and then retry the operation. */
		invalidSnapLabel(142),
		/** The operation cannot complete because the rollback priority you specified is not between 0 and 4. Please specify a value in this range and then retry the operation. */
		invalidRollbackPriority(143),
		/** The operation cannot complete because the warning threshold you specified is not between 0 and 100 or is higher than critical threshold. Please specify a value in this range and then retry the operation. */
		invalidWarnThreshold(144),
		/** The operation cannot complete because the volume you specified is a snapshot repository volume. You cannot map a logical unit number (LUN) or host to a snapshot repository volume. */
		cannotMapVolume(145),
		/** The format volume operation cannot complete because the specified volume is used in a configuration that does not support format. */
		cannotFormatVolume(146),
		/** The operation cannot complete because the drive-side interface is SCSI not Fibre Channel. */
		dstNotFibre(147),
		/** The operation cannot complete because the capacity you specified for the repository volume is less than the minimum size required. */
		repositoryTooSmall(148),
		/** The operation cannot complete because the snapshot repository volume is failed. Please use the Recovery Guru to resolve the problem. */
		repositoryFailed(149),
		/** The operation cannot complete because the base volume associated with this snapshot failed. Please use the Recovery Guru to resolve the problem. */
		baseVolumeFailed(150),
		/** The operation cannot complete because the base volume associated with this snapshot is offline. Please use the Recovery Guru to resolve the problem. */
		baseVolumeOffline(151),
		/** The create snapshot operation cannot complete because a base volume initialization is in progress. Please wait until the initialization completes and then retry the operation. */
		baseVolumeFormatting(152),
		/** The operation cannot complete because the command to create the mirror repository volumes was unsuccessful. Please retry the operation. */
		metadataVolNonexistent(153),
		/** The operation cannot complete because the remote volume mirroring feature is disabled. */
		rvmFeatureDisabled(154),
		/** The operation cannot complete because there are mirrors (primary or secondary) present on the array. */
		mirrorsPresent(155),
		/** The operation cannot complete because the remote volume mirroring feature has not been activated. */
		rvmFeatureDeactivated(156),
		/** The operation cannot complete because the maximum number of mirror volumes have been created on the local storage array. */
		maxMirrorsExceeded(157),
		/** The operation cannot complete because the base volume for a potential mirror was invalid. */
		invalidMirrorCandidateVol(158),
		/** The operation cannot complete because the selected volume is not a mirror volume. */
		invalidMirrorvol(159),
		/** The operation cannot complete because mirror repository volumes already exist. Please deactivate the Remote Volume Mirroring premium feature. */
		metadataAlreadyExists(160),
		/** The operation cannot complete because there are missing children for the mirror repository volume. */
		metadataMissing(161),
		/** The operation cannot complete because there are offline children for the mirror repository volume. */
		metadataOffline(162),
		/** The operation cannot complete because there are reconfiguring children for the mirror repository volume. */
		metadataReconfiguring(163),
		/** The operation cannot complete because the role of the local volume was unable to be changed. Please retry the operation. If the operation still cannot complete, please use the Recovery Guru to correct this condition or contact your Technical Support Representative. */
		localRoleChangeFailed(164),
		/** Not Used */
		remoteRoleChangeFailed(165),
		/** Not Used */
		localRoleChangeSuccessful(166),
		/** The mirror relationship was successfully removed from the local volume. However, a communication error prevented the mirror relationship from being removed from the associated remote volume in the mirrored pair. Go to the remote storage array and remove the mirror relationship. */
		onlyLocalMirrorDeleted(167),
		/** The operation cannot complete because there are no mirror candidates on the remote storage array. */
		noValidMirrorCandidate(168),
		/** The operation cannot complete because the maximum number of mirror volumes has been created on the remote storage array. */
		remoteMaxMirrorsExceeded(169),
		/** The operation cannot complete because the remote volume mirroring feature is disabled on the remote storage array. */
		remoteRvmFeatureDisabled(170),
		/** The operation cannot complete because the metadata volume is not present on the remote storage array. */
		remoteMetadataVolNonexistent(171),
		/** The operation cannot complete because of an internal error. Please contact your Technical Support Representative. */
		notRegistered(172),
		/** The operation cannot complete because the configuration number on the remote storage array is invalid. */
		remoteInvalidCfgGen(173),
		/** The local primary volume was successfully demoted to a secondary role, but the command to promote the remote secondary volume to a primary role did not complete successfully. Please use the Recovery Guru to correct this condition. */
		localRoleChangedNotForced(174),
		/** The remote primary volume was successfully demoted to a secondary role, but the command to promote the local secondary volume to a primary role did not complete successfully. Please use the Recovery Guru to correct this condition. */
		remoteRoleChangedLocalFailed(175),
		/** The operation cannot complete because the local storage array was unable to create/delete a host cluster (group) or host assignment for the remote volume or the remote storage array was unable to create/delete a host cluster (group) or host assignment for the local volume. Please retry the operation. */
		rvmSpmError(176),
		/** The operation cannot complete because the authentication failed on the remote storage array. */
		remoteAuthFailPassword(177),
		/** The operation cannot complete because the selected remote storage array does not support the version of Remote Volume Mirroring currently running on this storage array. Please upgrade the remote storage array's management software or select another storage array. */
		rvmVersionMismatch(178),
		/** The operation cannot complete due to an unknown failure at the remote storage array. Please retry the operation at a later time. */
		rvmRemoteArrayError(179),
		/** The operation cannot complete because the storage array cannot comunicate with the remote storage array to complete this request. Possible causes include network or connection problems, or no power to the storage array. Check these possible causes and then retry the operation. */
		rvmCommunicationError(180),
		/** The operation cannot be completed because fibre channel mirroring may not be activated, or the mirror channel is being used exclusively by a host. */
		rvmFibreError(181),
		/** The operation cannot complete because the local volume is not a primary volume. */
		mirrorVolNotPrimary(182),
		/** The operation cannot complete because the selected volume is not in a synchronized mirror state. Please wait until the mirrored pair is synchronized and then retry the operation. */
		secNotPromoteable(183),
		/** The operation cannot complete because the selected volume is not in a synchronized mirror state. Please wait until the mirrored pair is synchronized and then retry the operation. */
		priNotDemoteable(184),
		/** The operation cannot complete because the selected volume is a mirror repository volume. To delete a mirror repository volume, deactivate the Remote Volume Mirroring premium feature. */
		metadataChildDeletion(185),
		/** The operation cannot complete because the selected volume is in a mirror relationship. Please remove the mirror relationship and then retry the operation. */
		rmtvolOrphanDeletion(186),
		/** The operation cannot complete because the Remote Volume Mirroring premium feature is not supported on this controller platform. */
		rvmActivateDisallowed(187),
		/** The operation cannot complete because the Tray ID number entered is invalid. Please enter a valid Tray ID number and retry the operation. If you are unsure of the Tray ID number, locate the enclosure. */
		invalidTrayref(188),
		/** The operation cannot complete because a selected volume is the last one belonging to its controller owner and could not be successfully deleted. Please manually delete the volume. */
		partialDeletion(189),
		/** The operation cannot complete because the logical unit number (LUN) is already in use by the Access Volume. */
		defaultUtmCollision(190),
		/** The operation cannot complete because the copy priority entered was not valid. Please enter a valid priority and retry the operation. Valid copy priorities include Lowest, Low, Medium, High and Highest. */
		invalidCopyPriority(191),
		/** The operation cannot complete because the volumes entered are not a valid copy pair. Please enter a valid copy pair and retry the operation. */
		invalidVolumecopyref(192),
		/** The attempt to change the parameters of the selected copy pair cannot complete because of an internal controller error. Please retry the operation. */
		copyChangeFailed(193),
		/** The operation cannot complete because the selected copy pair is currently in a Pending, In Progress, or Failed state. Please (1) wait for the copy operation to complete if it is Pending or In Progress, or (2) clear the Failed state using the storage management software. Then, retry the operation. */
		copyActive(194),
		/** The operation cannot complete because the selected copy pair is currently in a Stopped or Completed State. */
		copyInactive(195),
		/** The operation cannot complete because the volume entered is not a valid source volume candidate. Possible causes include: the volume is a secondary volume in a mirrored pair, a mirror repository volume, a snapshot repository volume, or is a target volume in a copy pair that is currently Pending, In Progress, or Failed. NOTE: If you received this error after attempting a Re-Copy operation, even though the Re-Copy command failed, any changes you made to the Copy Priority as a result of that command were successfully completed. */
		copyIncompatibleSource(196),
		/** The operation cannot complete because the volume entered is not a valid target volume candidate. Possible causes include: the volume is a secondary volume in a mirrored pair, a mirror repository volume, a snapshot repository volume, a snapshot volume, a base volume of an active snapshot volume, a source volume in a copy pair that is currently Pending, In Progress, or Failed, or is the same volume that you entered as the source volume for this copy pair. Please select a different target volume and then retry the operation. NOTE: If you received this error after attempting a Re-Copy operation, even though the Re-Copy command failed, any changes you made to the Copy Priority as a result of that command were successfully completed. */
		copyIncompatibleTarget(197),
		/** The operation cannot complete because the source volume entered is missing. NOTE: If you received this error after attempting a Re-Copy operation, even though the Re-Copy command failed, any changes you made to the Copy Priority as a result of that command were successfully completed. */
		copyGhostSource(198),
		/** The operation cannot complete because the target volume entered is missing. NOTE: If you received this error after attempting a Re-Copy operation, even though the Re-Copy command failed, any changes you made to the Copy Priority as a result of that command were successfully completed. */
		copyGhostTarget(199),
		/** The operation cannot complete because the source volume entered does not exist. The source volume may have been deleted by a user on another storage management station accessing this storage array. */
		copyInvalidSourceRef(200),
		/** The operation cannot complete because the target volume entered does not exist. The target volume may have been deleted by a user on another storage management station accessing this storage array. */
		copyInvalidTargetRef(201),
		/** The operation cannot complete because the source volume entered is not in an Optimal or Degraded state. NOTE: If you received this error after attempting a Re-Copy operation, even though the Re-Copy command failed, any changes you made to the Copy Priority as a result of that command were successfully completed. */
		copyInvalidSourceState(202),
		/** The operation cannot complete because the target volume entered is not in an Optimal state. NOTE: If you received this error after attempting a Re-Copy operation, even though the Re-Copy command failed, any changes you made to the Copy Priority as a result of that command were successfully completed. */
		copyInvalidTargetState(203),
		/** The operation cannot complete because the source volume entered is currently undergoing a reconfiguration operation. Please wait until the reconfiguration operation completes and then retry the operation. NOTE: If you received this error after attempting a Re-Copy operation, even though the Re-Copy command failed, any changes you made to the Copy Priority as a result of that command were successfully completed. */
		copySourceReconfig(204),
		/** The operation cannot complete because the target volume entered is currently undergoing a reconfiguration operation. Please wait until the reconfiguration operation completes and then retry the operation. NOTE: If you received this error after attempting a Re-Copy operation, even though the Re-Copy command failed, any changes you made to the Copy Priority as a result of that command were successfully completed. */
		copyTargetReconfig(205),
		/** The operation cannot complete because the target volume must be of equal or larger capacity than the source volume. Please select a different target volume or increase the capacity of the target volume entered and then retry the operation. NOTE: If you received this error after attempting a Re-Copy operation, even though the Re-Copy command failed, any changes you made to the Copy Priority as a result of that command were successfully completed. */
		copyTargetTooSmall(206),
		/** The operation cannot complete because the target volume entered is already a target volume for another source volume. Please select a different target volume or remove the copy pair where this target volume currently resides. Then retry the operation. */
		copyTargetLimit(207),
		/** The operation cannot complete because the maximum number of copy pairs have been created for this storage array. */
		maxVolumeCopysExceeded(208),
		/** The operation cannot complete because the source volume entered has a SCSI-2 or persistent reservation placed on it. Please release the reservation at the host and then retry the operation. NOTE: If you received this error after attempting a Re-Copy operation, even though the Re-Copy command failed, any changes you made to the Copy Priority as a result of that command were successfully completed. */
		copySourceReservation(209),
		/** The operation cannot complete because the target volume entered has a SCSI-2 or persistent reservation placed on it. Please release the reservation at the host and then retry the operation. NOTE: If you received this error after attempting a Re-Copy operation, even though the Re-Copy command failed, any changes you made to the Copy Priority as a result of that command were successfully completed. */
		copyTargetReservation(210),
		/** The operation cannot complete because the source volume entered is currently initializing. Please wait for the initialization to complete and then retry the operation. NOTE: If you received this error after attempting a Re-Copy operation, even though the Re-Copy command failed, any changes you made to the Copy Priority as a result of that command were successfully completed. */
		copySourceFormat(211),
		/** The operation cannot complete because the target volume entered is currently initializing. Please wait for the initialization to complete and then retry the operation. NOTE: If you received this error after attempting a Re-Copy operation, even though the Re-Copy command failed, any changes you made to the Copy Priority as a result of that command were successfully completed. */
		copyTargetFormat(212),
		/** The attempt to start the copy operation failed because of an internal controller error. Please retry the operation. NOTE: If you received this error after attempting a Re-Copy operation, even though the Re-Copy command failed, any changes you made to the Copy Priority as a result of that command were successfully completed. */
		copyStartFailed(213),
		/** The attempt to stop the copy operation failed because of an internal controller error. Please retry the operation. */
		copyStopFailed(214),
		/** The operation cannot complete because the Volume Copy premium feature is disabled. */
		volcopyFeatureDisabled(215),
		/** The operation cannot complete because either the volume entered is a read-only target volume or it is a mirror secondary volume. Please either disable read-only or remove the mirror relationship. Then retry the operation. */
		writeLock(216),
		/** The reconfiguration operation cannot complete because of one of the following reasons: (1) the volume contains unreadable sectors. Check the Recovery Guru for an unreadable sectors problem and follow the recommended procedure. (2) the volume, or another volume that resides in the same volume group, is a source or target volume in a copy pair that is currently in a Pending, In Progress or Failed state, or the mirror volume is not optimal. Please either wait for the copy operation to complete if it is Pending or In Progress, or clear the Failed state, or restore the mirror volume back to an optimal state. Then, retry the reconfiguration operation. */
		cannotReconfigure(217),
		/** The operation cannot complete because the storage array is in a locked out mode. This mode occurs when too many incorrect passwords have been attempted over a 10-minute interval. The storage array will remain in the locked out mode for 10 minutes, during which, any operations that require an Administrator password will fail. Please wait and then retry the operation. */
		authFailContLockout(218),
		/** The operation cannot complete because the volume has a persistent reservation placed on it. Please release the reservation at the host and then retry the operation. If you still have problems, contact your Technical Support Representative. */
		prReservationConflict(219),
		/** The operation cannot complete because a volume registration could not be cleared. Please retry the operation. If this message persists, contact your Technical Support Representative. */
		regDeleteFailed(220),
		/** The operation cannot complete because an NVSRAM configuration setting indicates that batteries should not be part of this storage array. However, if you have batteries in this storage array, contact your Technical Support Representative to fix the NVSRAM setting to match your configuration. If you were attempting to reset the battery age, wait until the battery becomes fully charged and then try the operation again. */
		batteryNotInConfig(221),
		/** The operation cannot complete because the battery was removed. */
		batteryMissing(222),
		/** The operation cannot complete because there may be a problem with the drive channel itself, its associated cable may not be properly connected, or there are no expansion drive trays in this storage array. */
		noChannel(223),
		/** The operation cannot complete because the selected volume is a secondary volume. Please select a primary volume and then retry the operation. */
		rvmOperNotAllowedOnSec(224),
		/** The change volume group to RAID 0 operation cannot complete because the volume group contains mirror repository volumes. Mirror repository volumes must be either RAID 1,3,5, or 6 to ensure data redundancy. */
		dataRedundancyRequired(225),
		/** The operation cannot complete because the source volume entered is also a primary volume in a mirrored pair, and there is currently an error preventing mirror communication with the remote storage array. This error may be intermittent. Please retry the operation. If the operation still cannot complete, please use the Recovery Guru to correct the mirror communication error and then retry the operation. */
		copySourceZeroCapacity(226),
		/** The operation cannot complete because you attempted a volume-to-LUN mapping with a LUN greater than 31 and at least one host type defined for the selected host/host ports is limited to accessing volumes with LUNs 0 to 31. Please retry the operation using LUN 0 to 31. */
		invHostlunDefineMapping(227),
		/** The operation cannot complete because you attempted to do one of the following operations. (1) change a volume-to-LUN mapping with a LUN greater than 31 and at least one host type defined for the selected host/host ports is limited to accessing volumes with LUNs 0 to 31. (2) move a volume-to-LUN mapping to a host that contains at least one defined host type that is limited to accessing volumes with LUNs 0 to 31. Please retry the operation and use LUN 0 to 31 or select a different host. */
		invHostlunMoveMapping(228),
		/** The operation cannot complete because you attempted to define or change a host type to one that can only access volumes with LUNs 0 to 31 and there is already at least one volume mapped to the selected host or host port using a LUN greater than 31. Please either select a host type that can access LUNs greater than 31 or change the existing volume mappings to LUNs 0 to 31, and then retry the operation. */
		invHostlunDefineHosttype(229),
		/** The operation cannot complete because you attempted to move a host to a host cluster (group) or host port to an existing host that has at least one volume already assigned with a LUN greater than 31 and the defined host type for the host/host port is limited to accessing volumes with LUNs 0 to 31. Change either the host type to one that can access LUNs greater than 31 or change the existing volume assignment(s) to LUNs 0 to 31, and then retry the operation. IMPORTANT: If you want to change the host type of the host port, you must first change it on the existing host and then move it. */
		invHostlunMoveHostport(230),
		/** The operation cannot complete because you attempted to download incompatible firmware. Contact your Technical Support Representative for downgrade and compatible firmware support information. */
		fwIncompatible(231),
		/** The operation cannot complete because you attempted to suspend an already suspended mirror. */
		mirrorAlreadySuspended(232),
		/** The operation cannot complete because the existing mirror repositories are not large enough to accommodate more mirrors. Please upgrade the mirror repositories and retry the operation. */
		insuffLocalMirRepResources(233),
		/** The operation cannot complete because the remote array's mirror repositories are not large enough to accommodate more mirrors. Please upgrade the remote array's mirror repositories and retry the operation. */
		insuffRemtMirRepResources(234),
		/** Unable to delete the following missing volumes because they currently have unreadable sectors. You must clear the unreadable sectors on these volumes before deleting them. Contact your technical support representative for assistance. */
		ghostHasUnreadableSectors(235),
		/** The communication test passed. Some pings timed out, but their retries succeeded. */
		rvmCommStatRecoveredTimeout(236),
		/** The communication test passed, although some pings had delayed response. */
		rvmCommStatRecoveredDelay(237),
		/** The operation cannot complete because the communication test could not start. */
		rvmCommStatNotReady(238),
		/** The operation cannot complete because a command to the remote volume timed out. */
		rvmCommStatTimeout(239),
		/** The operation cannot complete because the channel to the remote array or volume is failed. */
		rvmCommStatChannelFailure(240),
		/** The operation cannot complete because the remote volume mirror network could not be accessed. */
		rvmCommStatNetworkFailure(241),
		/** The operation cannot complete because the remote volume was not found. */
		rvmCommStatDeviceMissing(242),
		/** The operation cannot complete because the remote volume did not permit a login. */
		rvmCommStatLoginRejected(243),
		/** The operation cannot complete because the remote volume login failed. */
		rvmCommStatLoginFailure(244),
		/** The operation cannot complete because the number of sample times exceeds the maximum. */
		rvmCommStatInvNumSamplesReqd(245),
		/** The operation failed because a quiescence or suspension is in progress. */
		rvmQuiescenceInProgress(246),
		/** The operation cannot complete because the volume reference is not a Remote Volume. */
		rvmInvalidRemotevol(247),
		/** The firmware download operation cannot complete because one or both of the controllers are currently performing a start-of-day operation. Please wait until the start-of-day operation completes, and then retry the firmware download operation. */
		sodInProgress(248),
		/** The drive firmware download operation cannot complete because one or more of the drives you selected has a Bypassed or Offline status and is inaccessible. */
		invalidDrives(249),
		/** The operation cannot complete because a download set identifier was incorrect. */
		invalidSetid(250),
		/** The operation cannot complete because the number of download sets exceeds the maximum allowed. */
		invalidSetsize(251),
		/** The operation cannot complete because not all the data for all download sets was received. */
		missingData(252),
		/** The operation cannot complete because request to quiesce the system failed. */
		quiescenceFailed(253),
		/** The operation cannot complete because file validation failed. */
		validationError(254),
		/** The operation cannot complete because the drive firmware download was halted by the user. */
		downloadHalted(255),
		/** The drive firmware download operation failed for all drives. */
		allFailed(256),
		/** The drive firmware download operation completed. The operation failed for some drives. */
		partialOk(257),
		/** The operation is no longer supported. */
		obsolete(258),
		/** Unable to clear the unreadable sectors on the drives associated with the selected volumes. There was a problem writing a known data pattern to these drives. Please retry the operation. If this message persists, contact your Technical Support Representative. */
		usmClearFailed(259),
		/** The operation cannot complete because the controller was placed in Service Mode at the request of a Technical Support Representative. A possible reason for this is that a problem with the storage array required diagnostic tests on this controller. Check to make sure the problem has been resolved. Place the controller Online. */
		controllerInServiceMode(260),
		/** Invalid drive. */
		invalidDrive(261),
		/** Dbm database error */
		databaseError(262),
		/** The automatic configuration has started as a background operation. */
		backgroundAutocfg(263),
		/** The automatic configuration cannot complete because another automatic configuration is in progress. */
		autocfgInprogress(264),
		/** The ESM firmware download cannot complete because the ESM firmware specified is not compatible with the storage array's controller firmware version. Please contact your Technical Support Representative to resolve this problem. */
		unsupportedLhaSataEsm(265),
		/** Parity scan failed. */
		parityScanFailed(266),
		/** Parity error repair failed. */
		parityRepairFailed(267),
		/** Media error repair failed. */
		mediaRepairFailed(268),
		/** The change role operation cannot complete because the data between the mirrored pair is unsynchronized. Please stop all I/O activity and then retry the operation. */
		mirrorDegraded(269),
		/** The operation cannot complete because your storage array contains mixed drive types and the Mixed Drive Types premium feature is disabled or out of compliance. Refer to the Recovery Guru for procedures on how to correct this condition. */
		prohibitedByMdtRestrictions(270),
		/** You have selected a key to enable a Gold Key dependent premium feature. You must enable the Gold Key premium feature on this storage array before you can enable a Gold Key-dependent premium feature. */
		prohibitedByGoldKeyRestrictions(271),
		/** You have selected a key to enable the following premium feature: Gold Key. A feature key is not required to use this feature on this storage array. */
		safeControllerNotSubjectToGoldKey(272),
		/** You have selected a key to enable the following premium feature: Mixed Drive Types. A feature key is not required to use this feature on this storage array. */
		safeMdtNotPremiumFeature(273),
		/** The operation cannot complete because the alarm module is not present. */
		alarmNotPresent(274),
		/** The Discrete Line Test did not execute to completion. */
		dltNotCompleted(275),
		/** Cannot turn on Ready to Remove LED due to dependency. */
		dependancyError(276),
		/** The CDM database is full. Free up space in the database and retry the operation. */
		cdmDatabaseFull(277),
		/** An operation could not be carried out because necessary pre-conditions were not true. */
		requiredConditionNotPresent(278),
		/** The diagnostic data capture request cannot complete because no diagnostic data is available. */
		ddcUnavail(279),
		/** The operation cannot complete because one or more parameters associated with the diagnostic data capture request is invalid. */
		ddcIllegalParam(280),
		/** The tag associated with a request for DDC data is invalid. */
		invalidDdcTag(281),
		/** A host type conflict was detected while trying to configure a pending host. */
		hosttypeConflict(283),
		/** A port conflict was detected while trying to configure a pending host. */
		portConflict(284),
		/** An invalid host type string for a pending host was detected. */
		invalidHosttypeString(285),
		/** An invalid port protocol for a pending host was detected. */
		invalidProtocol(286),
		/** The supplied pending host definition is missing ports compared to its matching discovered host. */
		portRemoved(287),
		/** A disable operation cannot be performed. An example is trying to disable a shipped-enabled feature. */
		disableNotPermitted(288),
		/** The operation cannot complete because the storage array has more than the allowed number of expansion enclosures. */
		prohibitedByDriveTrayLimit(289),
		/** The supplied component reference does not refer to an ESM */
		invalidEsmref(290),
		/** A bundle migration is invalid and cannot be performed. */
		invalidBundleMigration(291),
		/** A bundle key cannot be validated as coming from an authorized source. */
		invalidBundleKey(292),
		/** The hot spare coverage is already adequate for the storage, therefore no additional hot spare drives were automatically assigned. */
		noSparesNeeded(293),
		/** The operation cannot complete because it is not allowed under the current feature bundle. */
		prohibitedByFeatureBundleViolation(294),
		/** An operation requested the controller to assign an unknown authentication method for a target. */
		invalidAuthMethod(295),
		/** The supplied secret does not conform to the formatting rules for the selected authentication method. */
		invalidSecret(296),
		/** An attempt was made to set an initiator secret to one that was already set for a target, or vice-versa. */
		secretAlreadyInUse(297),
		/** An attempt was made to automatically refresh network parameter information, but the configuration method was set for manual update. */
		manualConfigModeSet(298),
		/** The operation cannot complete because there are no active iSCSI sessions. */
		noIscsiSessions(299),
		/** The supplied interface reference is invalid. */
		invalidInterfaceref(300),
		/** The operation cannot complete because of iSCSI initiator topology conflicts. */
		initiatorConflict(301),
		/** The pending host could not be configured because the pending host definition is missing the iSCSI initiators discovered on the corresponding physical host. */
		initiatorRemoved(302),
		/** The snapshot cannot be recreated because the base volume has been resized. Instead of recreating the snapshot, delete the snapshot and create another one. */
		basevolSizeChanged(303),
		/** The operation cannot complete because a referenced volume group doesn't exist. */
		volumeGroupNotExist(400),
		/** The operation cannot complete because a volume group is not online */
		volumeGroupNotOnline(401),
		/** A volume group state transition could not be performed because the group is using a hot spare drive in place of a failed drive. */
		volumeGroupHasHotspare(402),
		/** The volume group state transition cannot be performed because the group is reconfiguring. */
		volumeGroupReconfiguring(403),
		/** The operation cannot complete because the volume group or disk pool is not in a valid state. */
		volumeGroupStateNotValid(404),
		/** An attempt was made to quiesce a controller that was not in the optimal state. */
		controllerNotOptimal(405),
		/** The operation cannot complete because it requires volume, volume group, or free extent capacity in excess of what is available. */
		insufficientCapacity(406),
		/** The operation cannot complete because a volume group is in the exported state. */
		volumeGroupExported(407),
		/** The Volume cannot be configured because it is not in a configurable state. */
		volumeNotConfigurable(408),
		/** The Volume Group cannot be configured because it is not in a configurable state. */
		volumeGroupNotConfigurable(409),
		/** A drive operation cannot be performed because the drive is not in the correct state for the operation. */
		invalidDriveState(410),
		/** An operation on a volume group is requested, but cannot be carried out because the volume group is undergoing reconstruction. */
		volumeGroupReconstructing(412),
		/** An operation on a volume group is requested, but cannot be carried out because the volume group is undergoing copyback. */
		volumeGroupUndergoingCopyback(413),
		/** A volume group state transition could not be performed because the group is not in the COMPLETE state, i.e, at least one drive is absent, unassigned, or offline. */
		volumeGroupNotComplete(414),
		/** A volume group state transition could not be performed because the group has failed drives. */
		volumeGroupHasFailedDrives(415),
		/** A volume group state transition could not be performed because the group has non-optimal volumes. */
		volumeGroupHasNonOptimalVols(416),
		/** A volume group state transition could not be performed because the group is part of a remote mirror relationship. */
		volumeGroupHasMirrorRelationship(417),
		/** A volume group state transition could not be performed because the group is part of a volume copy relationship. */
		volumeGroupHasVolcopyRelationship(418),
		/** A volume group state transition could not be performed because the group contains metadata volumes for support of the remote mirroring feature. */
		volumeGroupHasMirroringMetadata(419),
		/** A volume group state transition could not be performed because the group has volumes that are assigned to a host cluster (group) or host. */
		volumeGroupHasMappedVols(420),
		/** A volume group state transition could not be performed because the group has volumes that have persistent reservations. */
		volumeGroupHasReservations(421),
		/** A volume group state transition could not be performed because one or more of the group's drives contain storage array metadata that is incompatible with this storage array. */
		volumeGroupHasIncompatibleDacstores(422),
		/** A volume group state transition could not be performed because it would cause the array volume limit to be exceeded. */
		volumeLimitExceeded(423),
		/** A volume group state transition could not be performed because the group has a RAID level that is unknown to the firmware. */
		volumeGroupHasUnknownRaidLevel(424),
		/** A volume group state transition could not be performed because the group has a RAID level that is known to the firmware, but is not supported. */
		volumeGroupHasUnsupportedRaidLevel(425),
		/** A volume group state transition could not be performed because the group has a clone opportunity. */
		volumeGroupHasCloneOpportunity(426),
		/** A volume group state transition could not be performed because the group is missing some drives. */
		volumeGroupHasInsufficientDrives(427),
		/** A volume group state transition could not be performed because there are failed volumes in the group. */
		volumeGroupHasFailedVols(428),
		/** The performance tiering feature could not be enabled because the array feature bundle settings do not allow performance level upgrade via feature key. */
		perfTierSafeUpgradeDisabled(429),
		/** A RAID-6-related operation was performed against firmware that does not support RAID 6. */
		raid6FeatureUnsupported(430),
		/** A RAID-6-related operation was performed against an array that can support RAID 6, but which does not have that feature enabled. */
		raid6FeatureDisabled(431),
		/** An attempt was made to install the RAID 6 feature on a controller where RAID 6 SAFE KEY upgrades are not enabled. */
		safeControllerNotSubjectToRaid6(432),
		/** An attempt was made to place a volume group in a forced state, but the volume group was not in the contingent state, as required. */
		volumeGroupNotContingent(433),
		/** An attempt was made to retrieve the results of a drive channel fault isolation diagnostic test before the test completed. */
		channelDiagsRunning(434),
		/** The diagnostics returned are incomplete because the operation was canceled or did not complete within its allocated time. */
		channelDiagsResultsPartial(435),
		/** A volume group state transition could not be performed because the group has a non-portable snapshot relationship. */
		volumeGroupHasSnapshotRelationship(436),
		/** The operation cannot complete because the storage array's current configuration violates Premium Feature limitations/compliance. */
		prohibitedBySafeViolation(437),
		/** A volume group could not be transitioned to forced state because it is a legacy volume group. */
		legacyVg(438),
		/** A volume group could not be transitioned to forced state because it has failed pieces, or does not have enough drives, or has an opportunity for cloning. */
		vgNotForceable(439),
		/** The drive channel fault isolation diagnostics function could not continue because of inability to acquire a lock. */
		channelDiagsLockErr(440),
		/** The drive channel fault isolation diagnostics function could not continue because of inability to quiesce I/Os. */
		channelDiagsNotQuiesced(441),
		/** The drive channel fault isolation diagnostics function could not continue because of inability to communicate with the alternate controller. */
		channelDiagsAltCommFailed(442),
		/** The drive channel fault isolation diagnostics function could not continue because of inability to prepare the channel for testing. */
		channelDiagsChanSetupFailed(443),
		/** The drive channel fault isolation diagnostics function could not continue because of inability to bypass a device. */
		channelDiagsDeviceBypassFailed(444),
		/** There are no diagnostics results to report - most likely because diagnostics were not started. */
		channelDiagsResultsNotAvailable(445),
		/** A drive in the storage array could not be spun up. */
		driveSpinUpError(446),
		/** A new drive does not match the type of the drive it is replacing. */
		driveTypeMismatch(447),
		/** The remote array node WWN and the local array node WWN are the same. */
		localRemoteArrayHasSameWwn(448),
		/** A volume group being imported has incompatible drives. */
		volumeGroupHasIncompatibleDrive(449),
		/** An attempt was made to import a volume group where the volumes in the volume group are overlapped with the dacstore area of the drives. */
		volumeGroupVolumeEncroachesOnDacstore(450),
		/** The operation cannot complete because a previous import is still in-progress. */
		volumeGroupImportInProgress(451),
		/** An attempt was made to import a volume group where the corresponding drives aren't spun up. To spin up the drives, it is necessary to get the import dependency information before importing the volume group.. */
		drivesNeedToBeSpunUp(452),
		/** An attempt was made to import or export a volume group when there are no native stable storage drives on the system. */
		noNativeSstor(453),
		/** The operation cannot complete because the increment (chunk) number supplied is outside the range of available increments. */
		noSuchDebugChunk(454),
		/** The state capture operation has been stopped because the storage array configuration has changed. Make sure there are no configuration changes occurring and then start the operation again. */
		debugInfoConfigChanged(455),
		/** The operation cannot complete because the controller is in a locked down state. */
		lockdown(456),
		/** A volume/volume group reconfiguration operation cannot be performed because it involves drives having overlapping DACSTORE regions. */
		drivesDacstoresOverlap(457),
		/** A volume expansion operation cannot complete because a volume is part of an asynchronous mirror relationship. */
		volumeHasAsyncMirror(458),
		/** A volume/volume group reconfiguration operation cannot be performed because there is insufficient space in the reconfiguration log. */
		reconfigLogSpaceError(459),
		/** The operation cannot complete because a volume group is inaccessible. */
		volumeGroupInaccessible(460),
		/** The operation cannot complete because a volume in the volume group is being initialized. */
		volumeInitializing(461),
		/** The operation cannot complete because the firmware could not allocate sufficient cache memory. */
		insufficientCache(462),
		/** The operation cannot complete because a volume is inaccessible. */
		volumeInaccessible(463),
		/** The operation cannot complete because no drives could be adopted as part of an import operation. */
		noDrivesAdopted(464),
		/** Some drives could be adopted, but not all eligible drives. */
		someDrivesAdopted(465),
		/** The export operation cannot complete for this volume group because one or more of its drive's configuration database region is undergoing a mirror synchronization process. The resynchronization process is a background operation and normally completes within 20 minutes. */
		exportingDrivesDatabaseResynchronizing(466),
		/** The export operation cannot complete for this volume group because one or more of its drive's configuration database region is not valid and is unusable. It is best to contact a Technical Support Representative for guidance but one possible remedy is to remove the drives associated with this volume group one at a time and then re-insert them to trigger a database resynchronization. However, this is not guaranteed to work. */
		exportingDrivesDatabaseFailed(467),
		/** The export operation cannot complete because one or more of the volume group's drives are quiesced. This generally occurs when firmware is being downloaded to the drive. Retry the operation at a later time. */
		exportingDrivesQuiesced(468),
		/** The battery service operation cannot be performed because a learn cycle is active. Retry the operation when the learn cycle has completed. */
		learnActiveTryLater(469),
		/** None of the drives in the array are in the security-locked state. */
		noLockedDrives(502),
		/** The operation cannot complete because the controller cannot enable the security capabilities of the drive. */
		driveSecurityEnabledFailed(504),
		/** The operation to set a new lock key failed for some drive */
		lockkeyFailed(505),
		/** The operation cannot complete because the drives are not secure-enabled. */
		invalidSecurity(506),
		/** The operation cannot complete because the drives are not secure-capable. */
		noFdeDrives(507),
		/** The operation cannot complete because either (1) the volume was specified to be non-secure but it is being created from a secure volume group or disk pool or (2) a secure request was made and the volume group or disk pool was already secure. */
		volumeGroupSecure(508),
		/** The key cannot be decrypted with the pass phrase supplied in the lock key blob. */
		invalidBlob(520),
		/** None of the security locked drives on the system could be unlocked using the lock key blob. */
		unlockFailed(521),
		/** The import operation cannot complete because a valid key has not been set on the target storage array. */
		noKeySet(522),
		/** The operation cannot complete because the generation of a new security key is currently in progress. */
		rekeyInProgress(523),
		/** Assigning a volume to the default host cluster (group) is not allowed. */
		defaultHostGroupMappingNotAllowed(524),
		/** A media scan is not allowed on the volume because it is part of a volume group or disk pool that consists of solid state drives. */
		ssdMediaScanNotAllowed(525),
		/** The operation cannot complete because the requested feature limit specified exceeds the maximum supported limit for this feature. */
		premiumFeatureLimitExceedsMaximum(531),
		/** The operation cannot complete because an evaluation key cannot be disabled. */
		disableEvaluationFeatureNotPermitted(532),
		/** The operation cannot complete because either: (1) one or more hosts involved has restricted visibility to LUN 0, or (2) hosts with differing LUN 0 visibility restrictions cannot be part of the same host cluster (group). */
		requestFailedDueToLun0Restrictions(537),
		/** The operation cannot complete because external security key management is already enabled. */
		externalKmsEnabled(538),
		/** The operation cannot complete because a new key cannot be obtained from the key server. */
		externalKmsFailed(539),
		/** The operation cannot complete because the external security key management is not enabled. */
		externalKmsNotEnabled(540),
		/** The operation cannot complete because no security key is needed. */
		keyNotNeeded(541),
		/** The operation cannot complete because the sequence number of the security key did not match the controller sequence number. */
		keyInvalidSequence(542),
		/** The operation cannot complete because the requested diagnostic is not running. */
		diagNotRunning(543),
		/** The operation cannot complete because the controller is not in service mode. */
		ctrlNotInServiceMode(544),
		/** The operation cannot complete because the specified premium feature was not found on this storage array. */
		invalidFeatureref(545),
		/** The operation cannot complete because the cache backup device does not exist. */
		cacheBackupDevNotExist(546),
		/** The operation cannot complete because the supplied security key does not match any on the controller. */
		noMatchingLockKeyIdFound(547),
		/** The operation cannot complete because the supplied security key failed validation. The security bundle (key and pass phrase) decrypted correctly, but the key did not match. */
		lockKeyValidationFailed(548),
		/** The operation cannot complete because there were too many unsuccessful security key validation attempts. */
		lockKeyValidationDisabled(549),
		/** The operation cannot complete because the external security key management feature is out of compliance. */
		externalKmsNotCompliant(550),
		/** The operation cannot complete because the request to the external security key manager timed out. */
		externalKmsTimeout(551),
		/** The external security key management feature cannot be disabled because the storage array does not have the key from the external server in memory. */
		cannotDisableNoKey(552),
		/** The feature cannot be enabled for an evaluation (trial) period because it has already been previously enabled. Only one evaluation period is allowed. */
		previouslyEnabledForEval(553),
		/** The feature cannot be enabled using a feature key file because it is not keyable. */
		featureNotKeyable(554),
		/** The operation cannot complete because an evaluation (trial) period is not supported for this feature. */
		evalNotSupported(555),
		/** The operation cannot complete because the raw data transfer type is unknown. */
		rawdataTransferBadType(556),
		/** The operation cannot complete because the raw data transfer has not been started. */
		rawdataTransferNotStarted(557),
		/** The operation cannot complete because another raw data transfer is already started. Another data transfer (retrieval or restore) cannot be started until the current transfer completes. */
		rawdataTransferAlreadyStarted(558),
		/** The operation cannot complete because the controller received a raw data transfer request from the host but it is still preparing for the transfer. */
		rawdataTransferPreparing(559),
		/** The operation cannot complete because a read error occurred when accessing a drive at the start of or during a data transfer. */
		rawdataTransferReadError(560),
		/** The operation cannot complete because the data transfer requires drives and no drives were available. */
		rawdataTransferNoDrives(561),
		/** The downloaded image did not pass a validity check; one possibility is that it does not contain the correct controller serial numbers for the two controllers in the array. */
		rawdataTransferInvalidImage(562),
		/** The operation cannot complete because the CRC value calculated by the controller for the data segment being transferred does not match the CRC value passed to the controller. */
		rawdataTransferCrcError(563),
		/** The operation cannot complete because during a raw data restoration, a write error occurred to a drive. */
		dbmRestoreWriteError(564),
		/** The operation cannot complete because there are not enough drives available upon which to restore the data. */
		dbmRestoreNoDrives(565),
		/** The operation cannot complete because a sequence number does not match the expected (incremented) value as part of the raw data transfer. */
		rawdataBadSeqNum(566),
		/** The operation cannot complete because this capability is not supported on this storage array. */
		invalidCapability(567),
		/** The operation cannot complete because the external security key to be validated is not in memory. */
		externalKeyNotInMemory(568),
		/** The operation cannot complete because the supplied security key ID is not valid. */
		invalidLockKeyId(569),
		/** The operation cannot complete because the volume protection (data assurance) is not valid. */
		invalidProtection(570),
		/** The operation cannot complete because the volume has a snapshot relationship. */
		volumeHasSnapshotRelationship(571),
		/** The operation cannot complete because the volume has a mirror relationship. */
		volumeHasMirrorRelationship(572),
		/** The operation cannot complete because the external security key manager has been disabled but there is no key. */
		externalKmsDisabledNoKey(573),
		/** The operation cannot complete because one controller must be placed offline before the database can be restored. */
		dbmRestoreAltCtlNotOffline(574),
		/** The operation cannot complete because the source and target volumes involved are not compatible (application tag owners do not match). */
		copyApptagMismatch(575),
		/** The operation cannot complete because the request is not valid for the given tray type. */
		invalidRequestForEnclosure(576),
		/** The operation cannot complete because a set of arguments was specified for a Debug Queue Trace Retrieval that do not match any existing trace files. There is nothing to return. */
		dqRetrieveNothingToTransfer(577),
		/** When configuring an iSCSI port, if a port's IPv4 Ethernet priority and IPv6 Ethernet priority are not the same value when the IPv4 VLAN ID and IPv6 VLAN ID are both the same value, the configuration request will be rejected with this return code. */
		invalidIscsiConfiguration(578),
		/** The operation cannot complete because the volume is part of a volume copy relationship. */
		volumeHasVolcopyRelationship(579),
		/** The volume cannot be assigned because it is data assurance (DA) protected and the host or host cluster (group) is not DA capable. */
		partPiIncapable(580),
		/** A host port or initiator cannot be added because it is not data assurance (DA) capable and the host or host cluster (group) contains a DA-capable volume. */
		requestFailedDueToPiRestrictions(581),
		/** The operation cannot complete because the raw data transfer has been canceled. */
		rawdataTransferUserCancelled(582),
		/** The operation cannot complete because the IP address being configured would be a duplicate of an existing address. */
		duplicateIscsiIpAddress(583),
		/** A port speed conflict was detected while attempting to configure a HIC port. The ports on the HIC must be configured to the same speed. */
		portSpeedConflict(584),
		/** The operation cannot complete because the vendor or product ID is not valid, there is bad IOM (ESM) status, or not all assigned drives are redundant. */
		factoryDefaultDownloadFailed(586),
		/** The operation cannot complete because the controller is unable to write the factory default information into the midplane EEPROM. */
		errorWritingToEeprom(587),
		/** Only a partial download occurred. The download was successful to one or more drawers but was unsuccessful to other drawers. Retry the operation. */
		factoryDefaultPartialUpdate(588),
		/** The operation cannot complete because the snapshot volume is in a disabled (stopped) state. */
		snapshotNotActive(589),
		/** The rollback operation cannot start because (1) the snapshot base or repository volumes associated with the reserved capacity are undergoing a reconfiguration operation, (2) another rollback is already in progress to the same base volume, (3) the base volume is either a source or target volume in a volume copy relationship or (4) a repository volume associated with the reserved capacity has unreadable sectors. */
		cannotRollback(590),
		/** A mirror synchronization is not possible (a new mirror cannot be created and the existing mirror synchronization cannot be resumed) due to a conflicting operation. Wait for the conflicting operation to complete and then retry the operation. */
		mirrorSyncNotPossible(591),
		/** The firmware download operation on the power supply failed. Retry the operation. */
		psuFirmwareDownloadFailed(592),
		/** The firmware download operation on the power supply cannot complete because of a manufacturing device code mismatch. */
		psuFirmwareUpdateMfgDeviceCodeMismatch(593),
		/** The firmware download operation on the power supply cannot complete because at least one of the requested power supplies does not have a redundant power supply. */
		psuFirmwareUpdateNotAllRedundant(594),
		/** The firmware download operation on the power supply cannot complete because at least one of the requested power supplies or its redundant power supply is not optimal. */
		psuFirmwareUpdateNotAllOptimal(595),
		/** The operation cannot complete because there is insufficient reserved capacity (repository). If possible, increase the reserved capacity and then retry the operation. */
		insufficientRepositoryCapacity(596),
		/** The snapshot volume rollback operation (start or resume) cannot complete because of errors accessing the repository volume associated with the reserved capacity. Check your storage management application for any errors noted on the reserved capacity (repository) and follow the recommended recovery procedures before retrying the operation. */
		rollbackStartFailure(597),
		/** The operation cannot complete because there is already another support bundle collection started (that is, there is an existing active lock). Wait until the current collection has completed and then retry the operation. */
		csbReserveFailed(598),
		/** The release operation on a support bundle reservation lock cannot complete because there is no active lock. */
		csbReleaseFailedNoLock(599),
		/** The release operation on a support bundle reservation lock cannot complete because a valid internal lock key was not specified. */
		csbReleaseFailedInvalidKey(600),
		/** The creation operation cannot complete because an SSD cache already exists. */
		flashcacheAlreadyExists(601),
		/** The operation cannot complete because the SSD cache premium feature is not enabled. */
		flashcacheFeatureDisabled(602),
		/** The suspend operation on the SSD cache cannot complete because it is already suspended. */
		flashcacheAlreadySuspended(603),
		/** The resume operation on the SSD cache cannot complete because it is not suspended. */
		flashcacheNotSuspended(604),
		/** The operation cannot complete because the SSD cache I/O (configuration) type specified is not valid. */
		flashcacheInvalidConfigType(605),
		/** The operation cannot complete because the snapshot group name is not valid or it already exists. */
		invalidPitGroupLabel(606),
		/** The operation cannot complete because the snapshot consistency group name is not valid or it already exists. */
		invalidPitConsistencyGroupLabel(607),
		/** The operation cannot complete because the snapshot group or snapshot consistency group automatic deletion limit specified is not valid. */
		invalidPitAutoDeleteLimit(608),
		/** The operation cannot complete because the snapshot group or snapshot consistency group full policy specified for the reserved capacity (repository) is not valid. */
		invalidPitRepositoryFullPolicy(609),
		/** The operation cannot complete because the name specified for the repository volume associated with the reserved capacity is not valid. */
		invalidConcatVolMemberLabel(610),
		/** The operation cannot complete because the capacity specified for the repository volume associated with the reserved capacity is less than the minimum allowed. */
		concatVolMemberTooSmall(611),
		/** The operation cannot complete because the snapshot group specified is not valid. */
		invalidPitGroupRef(612),
		/** The operation cannot complete because the snapshot image specified is not valid. */
		invalidPitRef(613),
		/** The operation cannot complete because a capacity expansion on this volume cannot occur due to feature restrictions. */
		dveNotAllowed(614),
		/** The operation cannot complete because the segment size specified for the volume cannot be changed due to feature restrictions. Please specify a different segment size. */
		dssNotAllowed(615),
		/** The supplied DPL Controller Health Image Tag is invalid. */
		dplCoreDumpInvalidTag(617),
		/** The operation cannot complete because the name specified for the snapshot volume is not valid. */
		invalidPitViewLabel(618),
		/** The operation cannot complete because the snapshot volume is not valid. */
		invalidPitViewRef(619),
		/** The operation cannot complete because the repository volume associated with the reserved capacity is not valid. */
		invalidConcatVolRef(620),
		/** The operation cannot complete because the volume is not associated with SSD cache. */
		notFlashcacheVol(621),
		/** The operation cannot complete because the SSD cache is being deleted. */
		flashcacheDeleted(622),
		/** The operation cannot complete because an attempt was made to enable SSD cache on a volume that already has it enabled. */
		flashcacheEnabled(623),
		/** The operation cannot complete because an attempt was made to enable SSD cache on a volume and the SSD cache does not exist. */
		flashcacheNotEnabled(624),
		/** The delete operation cannot complete because the volume is associated with SSD cache. */
		noRepDeletion(625),
		/** The operation cannot complete because the maximum number of snapshot images per snapshot group or snapshot consistency group has been reached. */
		maxPitsPerGroupExceeded(626),
		/** The operation cannot complete because the maximum number of snapshot images has been reached. */
		maxPitsExceeded(627),
		/** The operation cannot complete because the maximum number of snapshot groups and snapshot consistency groups per base volume has been reached. */
		maxPitGroupsPerBaseExceeded(628),
		/** The operation cannot complete because the maximum number of snapshot groups has been reached. */
		maxPitGroupsExceeded(629),
		/** The operation cannot complete because the maximum number of snapshot volumes per snapshot image has been reached. */
		maxViewsPerPitExceeded(630),
		/** The operation cannot complete because the maximum number of snapshot volumes has been reached. */
		maxViewsExceeded(631),
		/** The operation cannot complete because the maximum number of snapshot consistency groups has been reached. */
		maxConsistencyGroupsExceeded(632),
		/** The operation cannot complete because the maximum number of snapshot consistency group members has been reached. */
		maxConsistencyGroupMembersExceeded(633),
		/** The operation cannot complete because the maximum number of volumes that can be assigned to hosts has been reached. */
		maxMappableVolumesExceeded(634),
		/** The operation cannot complete because the specified snapshot image is not the oldest. You must delete snapshot images from oldest to newest. */
		notOldestPit(635),
		/** The operation cannot complete because the snapshot volume is disabled (stopped) or failed. */
		viewStopped(636),
		/** The operation cannot complete because the maximum number of repository volumes associated with the reserved capacity has been reached. */
		concatMemberLimitExceeded(637),
		/** The operation cannot complete because another operation is in progress on the volume or the volume is already a member. */
		invalidMemberVol(638),
		/** The operation cannot complete because the volume is assigned to a host. */
		memberVolMapped(639),
		/** The operation cannot complete because the member volume is failed or missing. */
		invalidMemberVolState(640),
		/** The operation cannot complete because the number of repository volumes (associated with the reserved capacity) specified for removal is not valid. You cannot remove the last repository volume. */
		invalidTrimCount(641),
		/** The operation cannot complete because this change is not allowed on an individual volume member that is part of a snapshot consistency group. */
		pitGroupInConsistencyGroup(642),
		/** The operation cannot complete because this change is not allowed on an individual snapshot image that is part of a snapshot consistency group. */
		pitInConsistencyGroup(643),
		/** The operation cannot complete because this change is not allowed on an individual snapshot volume that is part of a snapshot consistency group. */
		pitViewInConsistencyGroup(644),
		/** The operation cannot complete because the member volume does not match the data assurance (DA) and/or security attributes of the existing members, or the member block size is incompatible with existing members or other associated volumes. */
		incompatibleMemberVol(645),
		/** The operation cannot complete because one of the repository members specified for removal is in use (has valid repository data) or a request has been made to delete a repository member but the associated base element (snapshot group, snapshot volume, etc.) is not being deleted. */
		volumeInUse(646),
		/** The operation cannot complete because synchronouos mirroring over iSCSI is not supported. */
		rvmOverIscsiNotSupported(647),
		/** The operation cannot complete because the asynchronous mirror consistency group name already exists. */
		arvmGroupUserLabelExists(648),
		/** The operation cannot complete because the asynchronous mirror consistency group specified is not valid. */
		arvmGroupDoesNotExist(649),
		/** The operation cannot complete because the asynchronous mirror consistency group must be empty. */
		arvmGroupNotEmpty(650),
		/** The operation cannot complete because the repository volume associated with the reserved capacity is in a failed state. */
		concatVolumeFailed(651),
		/** The operation cannot complete because the snapshot consistency group specified is not valid. */
		invalidPitConsistencyGroupRef(652),
		/** The operation cannot complete because the snapshot volume specified for the snapshot consistency group is not valid. */
		invalidPitConsistencyGroupViewRef(653),
		/** The operation cannot complete because the snapshot volume name for the snapshot consistency group is not valid. */
		invalidPitConsistencyGroupViewLabel(654),
		/** The operation cannot complete because the alternate controller is not in a state that allows the operation. */
		alternateRequiredForOperation(655),
		/** The snapshot image indicated for the specified snapshot volume is not valid. Possible causes are (1) the snapshot image and snapshot volume specified are from different base volumes (they must be the same base volume) or (2) the snapshot image currently has a non-optimal status. */
		invalidPitForView(656),
		/** The volume cannot be added to the snapshot consistency group because it would cause the snapshot consistency group to become bound to more than one asynchronous mirror group. */
		consistencyGroupArvmBindingConflict(657),
		/** The operation cannot complete because the desired change is disallowed when the snapshot group or snapshot consistency group is associated with one or more volumes in an asynchronous mirroring relationship. */
		attributeFixedByArvm(658),
		/** The operation cannot complete because the associated object is in use for a Volume Copy operation. The object could be a snapshot group, source snapshot volume, or the target volume. */
		operationFailedVolumeCopyClone(659),
		/** The creation of a snapshot image was put in the pending state because one or more volumes associated with the operation are part of a mirroring relationship that is currently resynchronizing. Once the resynchronization has completed, the creation will automatically complete and the pending state will be cleared. */
		pitCreatePending(660),
		/** The operation cannot complete because the source database image specified for a retrieval or restoration does not exist or cannot be read. */
		dbmDbSourceUnavailable(661),
		/** The operation cannot complete because the source database image specified for the restoration does not match what is known about the previous configuration database. It could be a foreign or stale image. Either specify a different database image or contact your Technical Support Engineer for assistance. */
		dbmRestoreSourceMismatch(662),
		/** The operation cannot complete because the critical threshold you specified is not between 0 and 100 or is lower than the warning threshold. Please specify a correct value and then retry the operation. */
		invalidCriticalThreshold(663),
		/** The volume group cannot be exported because it has one or more volumes that are part of an asynchronous mirror relationship. These mirror relationships must be deleted before the volume group can be exported. */
		volumeGroupHasArvmRelationship(664),
		/** The operation cannot complete because either a secondary volume recovery point needs to be deleted or the reserved capacity (repository) of a secondary volume needs to be increased. */
		arvmRecoveryPointDeletionRequired(665),
		/** The operation cannot complete because there is at least one snapshot group associated with the volume group. */
		volumeGroupHasPitgroupRelationship(666),
		/** The volume group cannot be exported because it has one or more snapshot images associated with it. These snapshot images must be deleted before the volume group can be exported. */
		volumeGroupHasPitviewRelationship(667),
		/** The volume group cannot be exported because it has reserved capacity (repository) configured on it. This reserved capacity must be deleted before the volume group can be exported. */
		volumeGroupHasConcatRelationship(668),
		/** The operation cannot complete because the SSD cache is suspended. */
		flashcacheSuspended(669),
		/** The operation cannot complete because the volume already has SSD cache enabled on it. */
		flashcacheAlreadyEnabled(670),
		/** The operation cannot complete because the database image being read is corrupted. Retry the operation. */
		dbmDbImageCorrupt(671),
		/** The operation cannot complete because a volume configured from a volume group cannot be used for the reserved capacity (repository) for an object derived from a disk pool. */
		illegalVolume(672),
		/** The operation cannot complete because the thin volume's reserved capacity (repository) specified is either greater than 256 GB or is not a multiple of 4 GB. */
		invalidRepositoryCapacity(673),
		/** The operation cannot complete because the maximum expansion capacity specified is not valid. */
		invalidProvisionedCapacityQuota(674),
		/** The operation cannot complete because you are trying to manually expand a thin volume's reserved capacity (repository) and the expansion policy specified is not valid. */
		invalidExpansionPolicy(675),
		/** The operation cannot complete because the thin volume's capacity specified is not valid (either less than 32 MB or greater than 63 TB or the capacity is smaller or equal to the existing capacity). Retry the operation with a valid value. */
		invalidVirtualCapacity(676),
		/** The operation cannot complete because the capacity of an individual repository associated with the reserved capacity cannot be increased. */
		cannotExpandConcatMember(677),
		/** The operation cannot complete because the new threshold is below the capacity that is currently being used. */
		thresholdBelowUsedCapacity(678),
		/** The operation cannot complete because a maximum expansion capacity value cannot be specified when the thin volume has an expansion policy set to manual. */
		invalidExpansionOperation(679),
		/** The operation cannot complete because an attempt was made to expand a thin volume's reserved capacity (repository) capacity beyond the thin volume's reported capacity limits. */
		repositoryFull(680),
		/** The reserved capacity (repository) could not be increased because there is not sufficient disk pool free capacity remaining. */
		insufficientExpansionSpace(681),
		/** The operation cannot complete because the reserved capacity (repository) specified is either greater than 256 GB or is not a multiple of 4 GB. */
		invalidExpansionSize(682),
		/** The operation cannot complete because the initialization action specified is not valid. */
		invalidReinitAction(683),
		/** The operation cannot complete because the reserved capacity (repository) specified for the initialization is either greater than 256 GB or is not a multiple of 4 GB. */
		invalidReinitCapacity(684),
		/** The secondary volume member referenced in the asynchronous mirror consistency group is not valid. */
		invalidIncompleteMemberRef(685),
		/** The operation cannot complete because it must be performed by the storage array that is acting in the primary role for this asynchronous mirror consistency group. */
		arvmGroupNotPrimary(686),
		/** The operation cannot complete because it must be performed by the storage array that is acting in the secondary role for this asynchronous mirror consistency group. */
		arvmGroupNotSecondary(687),
		/** The operation cannot complete because a volume member of the asynchronous mirror consistency group is in a failed state. */
		arvmMemberFailed(688),
		/** The operation cannot complete because it can only be performed on an asynchronous mirror consistency group that is suspended. */
		arvmGroupNotSuspended(689),
		/** The operation cannot complete because of the current state of the asynchronous mirror consistency group or one of its volume members. */
		arvmInvalidMirrorState(690),
		/** The operation cannot complete because the volume specified is already part of a mirror relationship. */
		arvmVolumeAlreadyInMirrorRelationship(691),
		/** The operation cannot complete because the maximum number of volume members per asynchronous mirror consistency group has been reached. */
		arvmMemberLimitExceeded(692),
		/** The suspend operation cannot complete because of an internal error. Please retry the operation. If this message persists, contact your Technical Support Engineer. */
		arvmSuspendFailure(693),
		/** The resume operation cannot complete because of an internal error. Please retry the operation. If this message persists, contact your Technical Support Engineer. */
		arvmResumeFailure(694),
		/** The manual synchronization operation cannot complete because of an internal error. Please retry the operation. If this message persists, contact your Technical Support Engineer. */
		arvmSynchronizeFailure(695),
		/** The operation cannot complete because the remote storage array specified was not found. */
		remoteTargetNotFound(696),
		/** The operation cannot complete because the volume member specified for the asynchronous mirror consistency group is not valid. */
		arvmMirrorMemberDoesNotExist(697),
		/** The operation cannot complete because the conversion of snapshot volumes (legacy) to snapshot groups would result in exceeding the maximum number of snapshot groups per base volume. */
		snapConversionTooManySnaps(698),
		/** The base volume has one or more snapshot repositories that are not specified as part of the conversion (i.e. no new repository labels specified for those volume(s)). */
		snapConversionMissingLabel(699),
		/** The operation cannot complete because the asynchronous mirroring feature is not activated. */
		arvmFeatureDeactivated(700),
		/** The operation cannot complete because the repository volume associated with the reserved capacity has security settings that are not compatible with the related base volume, or a mirror primary/secondary volume. */
		incompatibleRepositorySecurity(701),
		/** The operation cannot complete because the secondary volume's security settings are not compatible with that of the primary volume. */
		incompatibleSecondarySecurity(702),
		/** The mirror channel protocol between a local and remote storage array do not match. */
		mirrorProtocolMismatch(703),
		/** The operation cannot complete because there are asynchronous mirrored pairs present on the storage array. */
		arvmAsyncMirrorGroupPresent(704),
		/** The operation cannot complete because the cache parameters cannot be changed on this volume. */
		cacheParametersNotChangeable(705),
		/** The operation cannot complete because the capacity specified exceeds the maximum capacity for the SSD cache. */
		flashcacheMaxCapacityExceeded(706),
		/** The operation cannot complete because the SSD cache is failed. */
		flashcacheFailed(707),
		/** The operation cannot complete because a Controller Health Image restoration is in progress. */
		dplCoreDumpRestoreInProgress(708),
		/** The operation cannot complete because the referenced asynchronous mirror consistency group has a volume that is no longer associated with it (orphaned) or the mirrored pair has an incomplete status. If the mirrored pair is incomplete, go to the appropriate storage array to complete the creation process. */
		arvmGroupHasIncompleteMember(709),
		/** The operation cannot complete because the mirroring connectivity test is already in progress. */
		arvmConnectivityTestAlreadyInProgress(710),
		/** The mirroring connectivity test failed because of a network error. */
		arvmConnectivityTestNetworkError(711),
		/** The mirroring connectivity test failed because it received a timeout error waiting for a response from the remote storage array. */
		arvmConnectivityTestRemoteTimeout(712),
		/** The mirroring connectivity test failed because it was not able to establish a connection with the remote storage array (internal login error). */
		arvmConnectivityTestLoginFailure(713),
		/** The mirroring connectivity test failed because it could not find the remote storage array (name service lookup error). */
		arvmConnectivityTestNameServiceError(714),
		/** The mirroring connectivity test failed because of a communication (test-unit ready) failure with the remote volume. */
		arvmConnectivityTestTurError(715),
		/** The mirroring connectivity test failed because the remote asynchronous mirror consistency group is missing. */
		arvmConnectivityTestMissingRemoteAmg(716),
		/** The mirroring connectivity test failed because the member volumes between the asynchronous mirror groups do not match. */
		arvmConnectivityTestAmgMemberMismatch(717),
		/** The specified mirror synchronization priority is not valid. Applicable values are 0 (lowest), 1 (low), (2) medium, (3) high, or 4 (highest). */
		invalidSyncPriority(718),
		/** The operation cannot complete because the specified recovery point age alert threshold is not valid. */
		invalidRecoveryPointAlertThreshold(719),
		/** The specified synchronization threshold is not valid because it cannot be used if the manual resynchronization method has been chosen. */
		invalidSyncAlertThreshold(720),
		/** The operation cannot complete because existing volumes must be specified when creating multiple objects. */
		mustSpecifyExistingVolumes(721),
		/** The mirroring connectivity test did not complete within the timeout specified. */
		arvmConnectivityTestTimeoutExceeded(722),
		/** The operation cannot complete because the maximum number of SSD cache objects has been reached. */
		flashcacheMaxLimitExceeded(723),
		/** The operation cannot complete because one or more volumes are using a non-secure capable SSD cache. */
		volsInVgUsingNonSecureCapableFlashcache(724),
		/** The operation cannot complete because security is disabled for the SSD cache. */
		volsInVgUsingSecureDisabledFlashcache(725),
		/** The operation cannot complete because the key file applied to the storage array to enable a premium feature contains a submodel ID that is not valid. The submodel ID in the key file should either be zero or should match the submodel ID of the storage array. Please contact your Technical Support Engineer for assistance. */
		invalidSubmodelId(726),
		/** The operation cannot complete because there is a mismatch between the limit value in the premium feature key and what the storage array was expecting. For example, the premium feature key may have been associated with a feature that has limit values. Therefore, the storage array was expecting the key to contain a limit value but the limit in the key is zero. This is not valid and therefore the key is rejected. */
		premiumFeatureLimitMismatch(727),
		/** The operation cannot be completed because the volume group is not importable. */
		volumeGroupNotImportable(728),
		/** The operation cannot be completed because of a primary cache size mismatch. */
		primaryCacheSizeMismatch(729),
		/** The operation cannot complete because the SSD cache name is already in use. */
		flashcacheUserLabelExists(730),
		/** The operation cannot complete because the maximum number of thin volumes allowed would be exceeded. */
		maxThinVolumesExceeded(731),
		/** The secondary volume does not have sufficient capacity for mirroring with the primary volume. It must have a capacity equal to or greater than the primary volume. */
		arvmInvalidSecondaryCapacity(732),
		/** A volume in an asynchronous mirror pair has been removed from the storage array that has the primary role but removal has failed on the secondary storage array. Go to the secondary storage array and remove the remaining volume in the mirrored pair. */
		arvmOnlyPrimaryMemberRemoved(733),
		/** A volume in an asynchronous mirror pair has been removed from the storage array that has the secondary role but removal has failed on the primary storage array. Go to the primary storage array and remove the remaining volume in the mirrored pair. */
		arvmOnlySecondaryMemberRemoved(734),
		/** The operation cannot complete because the asynchronous mirror consistency group is currently suspended. */
		arvmInvalidAmgRequestWhileSuspended(735),
		/** The requested manual synchronization cannot be started because a synchronization is already in progress. */
		arvmManualSyncAlreadyInProgress(736),
		/** The requested manual synchronization cannot be started because the minimum wait time between synchronizations has not been met. */
		arvmManualSyncRetryTooSoon(737),
		/** The operation cannot complete because an attempt had been made to delete a disk pool that still has volumes configured on it. The volumes must be deleted before deleting the disk pool. */
		diskPoolNotEmpty(738),
		/** SSD cache cannot be enabled on this volume because either (1) the volume is comprised of SSD drives, (2) the volume and the SSD cache do not have compatible attributes or (3) the volume state is not valid for enabling SSD cache. */
		flashCacheInvalidBaseVol(739),
		/** The operation cannot complete because FDE is not allowed for SSD cache. */
		flashCacheFdeEnablementDisallowed(740),
		/** The operation cannot complete because the asynchronous mirroring feature has not been activated on the remote storage array. */
		remoteArvmFeatureDeactivated(741),
		/** The operation cannot complete because the asynchronous mirroring feature is disabled on the remote storage array. */
		remoteArvmFeatureDisabled(742),
		/** The operation cannot complete because the associated asynchronous mirror group is missing on the remote storage array. */
		arvmOrphanGroup(743),
		/** The operation cannot complete because the associated asynchronous mirror consistency group member is missing on the remote storage array. */
		arvmOrphanMember(744),
		/** The asynchronous mirror consistency group member cannot be recovered because an associated volume (base, repository associated with reserved capacity, or remote volume) is not currently available. */
		volumeNotAvailable(745),
		/** The asynchronous mirror consistency group member cannot be recovered because the associated base volume has unreadable sectors. */
		volumeHasUnreadableSectors(746),
		/** The operation cannot complete because the thin provisioning premium feature is not enabled. */
		thinProvisioningFeatureDisabled(747),
		/** The operation cannot complete because the snapshot premium feature is not enabled. */
		pitGroupsFeatureDisabled(748),
		/** The operation cannot complete because the disk pool limit would be exceeded. */
		exceedDiskPoolLimit(749),
		/** The operation cannot complete because the SSD cache is in a degraded state. */
		flashcacheDegradedState(750),
		/** The operation cannot complete because the SSD cache is data assurance (DA) protected and an attempt was made to add a drive that is not DA capable. */
		flashcacheNonDaCapableDriveDisallowed(751),
		/** The operation cannot complete because the maximum number of asynchronous mirror consistency groups allowed would be exceeded. */
		arvmMaxAsyncMirrorGroupsExceeded(752),
		/** The operation cannot complete because the maximum number of asynchronous mirror relationships allowed per storage array would be exceeded. */
		arvmMaxMirrorsPerArrayExceeded(753),
		/** The operation cannot complete because the maximum number of all mirror relationships (asynchronous and synchronous) per storage array would be exceeded. */
		maxTotalMirrorsPerArrayExceeded(754),
		/** The operation cannot complete because the disk pool capacity would be exceeded. */
		exceedDiskPoolCapacity(755),
		/** The operation cannot complete because the maximum volume capacity would be exceeded. */
		exceedMaxVolumeCapacity(756),
		/** The operation cannot complete because the maximum number of asynchronous mirror consistency groups allowed would be exceeded on the remote storage array. */
		arvmRemoteMaxAsyncMirrorGroupsExceeded(757),
		/** The operation cannot complete because the maximum number of asynchronous mirror relationships allowed per storage array would be exceeded on the remote storage array. */
		arvmRemoteMaxMirrorsPerArrayExceeded(758),
		/** The operation cannot complete because the maximum number of all mirror relationships (asynchronous and synchronous) per storage array would be exceeded on the remote storage array. */
		remoteMaxTotalMirrorsPerArrayExceeded(759),
		/** The operation cannot complete because the synchronization interval specified is not valid. */
		arvmInvalidSyncInterval(760),
		/** The operation cannot complete because there is insufficient controller memory on the remote array. */
		remoteNoHeap(761),
		/** The operation cannot complete because there was an internal target error on the remote array. */
		remoteInternalError(762),
		/** The operation cannot complete because there was a host mapping error on the remote array. */
		remoteRvmSpmError(763),
		/** The operation cannot complete because the asynchronous mirror consistency group member does not exist on the remote storage array. */
		arvmRemoteMirrorMemberDoesNotExist(764),
		/** The operation cannot complete because the asynchronous mirror consistency group name is already in use on the remote storage array. */
		arvmRemoteGroupUserLabelExists(765),
		/** The operation cannot complete because it must be performed while the remote storage array is acting in the secondary role for this asynchronous mirror consistency group. */
		arvmRemoteGroupNotSecondary(766),
		/** The operation cannot complete because the asynchronous mirror consistency group does not exist on the remote storage array. */
		arvmRemoteGroupDoesNotExist(767),
		/** The operation cannot complete because the volumes in the storage arrays have incompatible volume data protection attributes. */
		remoteInvalidProtection(768),
		/** The operation cannot complete because of a database error on the remote storage array. */
		remoteDatabaseError(769),
		/** The operation cannot complete because the asynchronous mirror consistency group must be empty (not have any mirrored pairs) on the remote storage array. */
		arvmRemoteGroupNotEmpty(770),
		/** The suspend operation cannot complete on the remote storage array because of an internal error. Please retry the operation. If this message persists, contact your Technical Support Engineer. */
		arvmRemoteSuspendFailure(771),
		/** The resume operation cannot complete on the remote storage array because of an internal error. Please retry the operation. If this message persists, contact your Technical Support Engineer. */
		arvmRemoteResumeFailure(772),
		/** The manual synchronization operation cannot complete on the remote storage array because of an internal error. Please retry the operation. If this message persists, contact your Technical Support Engineer. */
		arvmRemoteSynchronizeFailure(773),
		/** The operation cannot complete because SSD cache performance modeling is in a state that is not valid for the attempted operation */
		flashcacheInvalidAnalyticsState(774),
		/** The operation cannot complete because synchronization is still in progress on the local storage array because of a capacity expansion on a volume. */
		arvmExpansionSynchronizationInProgress(775),
		/** The operation cannot complete because synchronization is still in progress on the remote storage array because of a capacity expansion on a volume. */
		arvmRemoteExpansionSynchronizationInProgress(776),
		/** The fault indication cannot be cleared because the underlying condition causing the fault still exists. */
		faultConditionStillExists(777),
		/** The operation must be performed on the alternate controller because there are communication issues from this controller to the remote storage array. */
		remoteTryAlternate(778),
		/** The asynchronous mirror consistency group has been removed from the local storage array but it was not removed on the remote storage array. Use the management software on the remote storage array to remove the mirror group. */
		arvmOnlyLocalAmgDeleted(779),
		/** The operation cannot complete because a role change is pending for the asynchronous mirror consistency group. */
		arvmRoleChangePending(780),
		/** The operation cannot complete because a role change is in progress for the asynchronous mirror consistency group. */
		arvmRoleChangeInProgress(781),
		/** The operation cannot complete because a member of the asynchronous mirror consistency group is in a stopped state. */
		arvmMemberStopped(782),
		/** The operation cannot complete because a reconstruction is already in progress. */
		reconstructionInProgress(783),
		/** The operation cannot complete because a copyback is in progress. */
		copybackInProgress(784),
		/** The Admin password is not set. */
		adminPasswordNotSet(785),
		/** The operation cannot complete because there are secure-capable drives in the storage array that are not locked and no key exists. */
		keyDoesNotExist(786),
		/** The operation cannot complete until recovery actions have been resolved. */
		takeRecoveryActionsFirst(787),
		/** The operation cannot complete because the controller health image has not completed backup to the pCache device */
		coredumpBackupInProgress(788),
		/** The operation cannot complete because synchronous mirroring (legacy RVM) does not support an asynchronous mode. */
		legacyRvmAsyncModeUnsupported(789),
		/** The operation cannot complete because an attempt was made to add a volume to a secondary asynchronous mirror consistency group and this volume does not match the primary volume (for example, the primary volume is thin and the new volume is not). */
		arvmIncorrectVolumeType(790),
		/** The operation cannot complete because the various settings and thresholds on a thin volume cannot be changed if the thin volume is a member of a secondary asynchronous mirror consistency group. */
		thinVolumeParametersCannotBeModified(791),
		/** The operation cannot complete because an attempt was made to add a thin volume to a primary asynchronous mirror consistency group but the remote storage array does not support mirroring thin volumes. */
		arvmRemoteThinNotSupported(792),
		/** The operation cannot complete because the provided SNMP community name is not valid. */
		snmpInvalidCommunityName(793),
		/** The operation cannot complete because the provided SNMP community permissions are not valid. */
		snmpInvalidCommunityPermission(794),
		/** The operation cannot complete on the designated SNMP community because it is not valid. */
		snmpInvalidCommunityRef(795),
		/** The operation cannot complete on the designated SNMP trap destination because it is not valid. */
		snmpInvalidTrapDestinationRef(796),
		/** The operation cannot complete because the provided IP address is not valid. */
		invalidIpAddress(797),
		/** The operation cannot complete because the maximum number of communities already exist. */
		snmpMaxCommunitiesExceeded(798),
		/** The operation cannot complete because the maximum number of trap destinations already exist. */
		snmpMaxTrapDestinationsExceeded(799),
		/** The operation cannot complete because a community already exists with the given name. */
		snmpCommunityNameInUse(800),
		/** The operation cannot complete because a trap destination already exists with the given destination address. */
		snmpTrapDestinationAddressInUse(801),
		/** The operation cannot complete because a valid SNMP system variable was not specified. */
		snmpUnknownSystemVariable(802),
		/** The operation cannot complete because a valid value for the specified SNMP system variable was not provided. */
		snmpInvalidSystemVariableValue(803),
		/** The operation cannot complete because the SNMP agent instances on the two controllers are currently incompatible. This would most like occur during a firmware upgrade. */
		snmpIncompatibleFirmware(804),
		/** The operation cannot complete because the SNMP agent is disabled on this array. */
		snmpAgentDisabled(805),
		/** The operation cannot complete because the SNMP agent failed to initialize. */
		snmpAgentInitFailed(806),
		/** The operation cannot complete because a thin provisioned volume that is part of a secondary asynchronous mirror group failed its initialization request. */
		arvmThinVolInitError(807),
		/** The operation cannot complete because a thin volume that is part of a secondary asynchronous mirror consistency group failed its initialization request. */
		arvmRemoteThinVolInitError(808),
		/** The operation cannot be completed because the specified SNMP trap destination is not reachable with the current controller IPV4 network configuration. This could be because: (1) IPV4 is not enabled on at least one port with an active connection on each controller OR (2) the following conditions exist on one or both controllers: (a) the controller is configured with a static IP address (i.e. does not obtain it's IP configuration via DHCP) AND (b) an IPV4 gateway is not assigned on that controller AND (c) the IP address of the controller and the specified trap destination address are not part of the same subnet */
		snmpIncompatibleIpv4Address(809),
		/** The operation cannot complete because the SNMP trap destination is not reachable with the current controller IPv6 network configuration. This is likely because IPv6 is not enabled on at least one port with an active connection on each controller. */
		snmpIncompatibleIpv6Address(810),
		/** The operation cannot complete because the number of drives selected is not valid or at least one of the selected drives cannot be removed from the pool. */
		drivesNotAvailableForRemoval(811),
		/** IPv4 support cannot be disabled because there are existing SNMP trap destinations configured with IPv4 addresses. */
		snmpCannotDisableIpv4(812),
		/** IPv6 support cannot be disabled because there are existing SNMP trap destinations configured with IPv6 addresses. */
		snmpCannotDisableIpv6(813),
		/** The operation cannot be completed because the resulting IPV4 network configuration would result in existing SNMP trap destinations becoming unreachable. On each controller, either (1) the controller IP address must be obtained via DHCP, (2) an IPV4 gateway must be assigned or (3) the controller IP address must be part of the same subnet as all IPV4 trap destination addresses. */
		snmpIpv4ConfigError(814),
		/** The operation cannot complete because an IOC Dump is currently in progress. */
		iocDumpInProgress(815),
		/** The operation cannot complete because an IOC Restore is currently in progress. */
		iocRestoreInProgress(816),
		/** The operation cannot complete because the supplied IOC Dump Tag is not valid. */
		iocDumpInvalidTag(817),
		/** The operation cannot complete because it is not supported on the IOM (ESM). */
		unsupportedEsmRequest(818),
		/** The operation cannot complete because it is invalid to have the I/O ports set for Static addressing and have the iSNS set for DHCP. */
		isnsDhcpNotSupported(819),
		/** The power cycle sequence cannot be performed on this drive because the volume group containing the drive is not redundant. */
		dpcVolumeGroupNotRedundant(821),
		/** The power cycle sequence cannot be performed on this drive because a volume containing the drive has not been initialized. */
		dpcVolumeNotInitialized(822),
		/** The power cycle sequence cannot be performed on this drive because an exclusive operation is active. */
		dpcExclusiveOperationActive(823),
		/** The power sequence failed because the controller firmware was unable to power up the drive. */
		dpcUnableToPowerUpDrive(824),
		/** The power cycle sequence cannot be performed on this drive because a format operation is active. */
		dpcFormatActive(825),
		/** The power cycle sequence cannot be performed on this drive because there are unreadable sectors present. */
		dpcUnreadableSectorsPresent(826),
		/** The power cycle sequence cannot be performed on this drive because a power cycle sequence is already in progress. */
		dpcPowerCycleAlreadyInProgress(827),
		/** The power cycle sequence cannot be performed on this drive because the enclosure containing the drive does not support power cycling a drive slot. */
		dpcEnclosureHardwareUnsupported(828),
		/** The power cycle sequence cannot be performed on this drive because the firmware on the enclosure containing the drive does not support power cycling a drive slot. */
		dpcEnclosureFwDownlevel(829),
		/** The drive copy operation cannot complete because another drive copy operation is already in progress on this volume group. */
		evacInProgress(832),
		/** The drive copy operation cannot be cancelled because the system detected that there is no operation currently in progress. */
		noEvacFound(833),
		/** The drive copy operation cannot complete because no hot spare exists that is appropriate for this volume group. */
		noHotspareAvailable(834),
		/** The operation could not be performed because a drive is undergoing a service operation. */
		driveServiceInProgress(835),
		/** The operation cannot complete because a segment size of 4096 is only allowed on volumes in volume groups that contain SSD drives. */
		hdd4kbSegmentsizeNotAllowed(836),
		/** The disk pool has no spare drive capacity to support the 'copy drive then fail' operation. */
		diskPoolNoSpareDrives(837),
		/** The disk pool has exceeded its spare capacity and can't support the 'copy drive then fail' operation. */
		diskPoolExceedSpareCapacity(838),
		/** Cannot perform the request because Auto Load Balancing has been disabled by user request. */
		autoLoadBalanceUserDisabled(875),
		/** Cannot perform the load balance request because of insufficient load history data. */
		autoLoadBalanceInsufficientStatistics(876),
		/** The load balance operation cannot be performed because the specified LoadBalanceAction is invalid. */
		invalidLoadBalanceAction(889),
		/** The load balance operation cannot be performed because the specified delay time is invalid. */
		invalidLoadBalanceDelay(890),
		/** The IP address specified conflicts with an address reserved for internal controller use. */
		reservedAddress(899),
		/** The operation cannot complete because the volume is still being created. Check the Operations in Progress indication and try again once the volume has finished its creation process. */
		volumeCreationInProgress(900),
		/** The operation cannot complete because the object associated with the specified ref cannot be found. */
		keyValueTagInvalidRef(901),
		/** The operation cannot complete because the input descriptor contains duplicate entries. */
		keyValueTagInvalidDuplicate(902),
		/** The Key Value pair cannot be deleted because it is currently in use. */
		keyValueTagInUse(903),
		/** The workload operation cannot complete because the object associated with the operation cannot be found. */
		workloadInvalidRef(904),
		/** The operation cannot complete because the object on which you are attempting to perform the operation cannot be found. */
		invalidKeyValueTagObjectReference(905),
		/** The operation cannot complete because of duplicate items in mapping request. */
		mappingInvalidDuplicate(906),
		/** This is returned if a download occurs and no reboot whatsoever is expected. */
		downloadCompleteNoReboot(907),
		/** This is returned at the completion of download, and only MSW is expected to reboot. */
		downloadCompleteMswOnlyReboot(908),
		/** The operation cannot complete because the workload name already exists. */
		workloadInvalidDuplicate(909),
		/** The volume-to-host assignment operation cannot complete because one of the objects associated with the operation cannot be found. */
		mappingInvalidRef(910),
		/** The deletion operation cannot complete because the workload is currently in use. */
		workloadInUse(911),
		__UNDEFINED(464378545);

		public final int value;

		private ReturnCode(int v) {
			this.value = v;
		}
}
