package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure provides general information about a storage array. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(849)
public class SAData implements Serializable {
	public SAData() {
	}

	/** An indication of whether the array needs attention. A value of true is returned if there are any components that have been marked failed for any reason. Otherwise, if all components are operating properly, a value of false is returned. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of whether the array needs attention. A value of true is returned if there are any components that have been marked failed for any reason. Otherwise, if all components are operating properly, a value of false is returned." , required = true)
	@XmlElement(required = true)
	private boolean needsAttention;

	/** @return An indication of whether the array needs attention. A value of true is returned if there are any components that have been marked failed for any reason. Otherwise, if all components are operating properly, a value of false is returned. */
	public boolean isNeedsAttention() {
		return this.needsAttention;
	}
	/** @param x An indication of whether the array needs attention. A value of true is returned if there are any components that have been marked failed for any reason. Otherwise, if all components are operating properly, a value of false is returned. */
	public void setNeedsAttention(boolean x) {
		this.needsAttention = x;
	}

	/** An indication of whether the array is in the process of recovering from a Needs Attention condition. A value of true indicates that no physical components are currently marked failed, but that some residual recovery activity (such as reconstruction, copyback, etc.) is still in progress. */
	@io.swagger.annotations.ApiModelProperty(value ="An indication of whether the array is in the process of recovering from a Needs Attention condition. A value of true indicates that no physical components are currently marked failed, but that some residual recovery activity (such as reconstruction, copyback, etc.) is still in progress." , required = true)
	@XmlElement(required = true)
	private boolean fixing;

	/** @return An indication of whether the array is in the process of recovering from a Needs Attention condition. A value of true indicates that no physical components are currently marked failed, but that some residual recovery activity (such as reconstruction, copyback, etc.) is still in progress. */
	public boolean isFixing() {
		return this.fixing;
	}
	/** @param x An indication of whether the array is in the process of recovering from a Needs Attention condition. A value of true indicates that no physical components are currently marked failed, but that some residual recovery activity (such as reconstruction, copyback, etc.) is still in progress. */
	public void setFixing(boolean x) {
		this.fixing = x;
	}

	/** The globally-unique identifier value for this storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="The globally-unique identifier value for this storage array." , required = true)
	@XmlElement(required = true)
	private SAIdentifier saId;

	/** @return The globally-unique identifier value for this storage array. */
	public SAIdentifier getSaId() {
		return this.saId;
	}
	/** @param x The globally-unique identifier value for this storage array. */
	public void setSaId(SAIdentifier x) {
		this.saId = x;
	}

	/** The name of the application-level entity required to manage configuration operations for the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="The name of the application-level entity required to manage configuration operations for the storage array." , required = true)
	@XmlElement(required = true)
	private String managementClassName;

	/** @return The name of the application-level entity required to manage configuration operations for the storage array. */
	public String getManagementClassName() {
		return this.managementClassName;
	}
	/** @param x The name of the application-level entity required to manage configuration operations for the storage array. */
	public void setManagementClassName(String x) {
		this.managementClassName = x;
	}

	/** The user-assigned label for the storage array. */
	@io.swagger.annotations.ApiModelProperty(value ="The user-assigned label for the storage array." , required = true)
	@XmlElement(required = true)
	private String storageArrayLabel;

	/** @return The user-assigned label for the storage array. */
	public String getStorageArrayLabel() {
		return this.storageArrayLabel;
	}
	/** @param x The user-assigned label for the storage array. */
	public void setStorageArrayLabel(String x) {
		this.storageArrayLabel = x;
	}

	/** The timestamp value for the time at which the responding controller last booted. Note that this value may differ between the individual controllers of a storage array. This value is defined in terms of the number of seconds since midnight GMT on January 1, 1970. */
	@io.swagger.annotations.ApiModelProperty(value ="The timestamp value for the time at which the responding controller last booted. Note that this value may differ between the individual controllers of a storage array. This value is defined in terms of the number of seconds since midnight GMT on January 1, 1970." , required = true)
	@XmlElement(required = true)
	private long bootTime;

	/** @return The timestamp value for the time at which the responding controller last booted. Note that this value may differ between the individual controllers of a storage array. This value is defined in terms of the number of seconds since midnight GMT on January 1, 1970. */
	public long getBootTime() {
		return this.bootTime;
	}
	/** @param x The timestamp value for the time at which the responding controller last booted. Note that this value may differ between the individual controllers of a storage array. This value is defined in terms of the number of seconds since midnight GMT on January 1, 1970. */
	public void setBootTime(long x) {
		this.bootTime = x;
	}

	/** The version identifier of the currently-installed array firmware. */
	@io.swagger.annotations.ApiModelProperty(value ="The version identifier of the currently-installed array firmware." , required = true)
	@XmlElement(required = true)
	private String fwVersion;

	/** @return The version identifier of the currently-installed array firmware. */
	public String getFwVersion() {
		return this.fwVersion;
	}
	/** @param x The version identifier of the currently-installed array firmware. */
	public void setFwVersion(String x) {
		this.fwVersion = x;
	}

	/** The version identifier of the "application" component of the currently-installed array firmware. */
	@io.swagger.annotations.ApiModelProperty(value ="The version identifier of the \"application\" component of the currently-installed array firmware." , required = true)
	@XmlElement(required = true)
	private String appVersion;

	/** @return The version identifier of the "application" component of the currently-installed array firmware. */
	public String getAppVersion() {
		return this.appVersion;
	}
	/** @param x The version identifier of the "application" component of the currently-installed array firmware. */
	public void setAppVersion(String x) {
		this.appVersion = x;
	}

	/** The version identifier of the "boot" component of the currently-installed array firmware. */
	@io.swagger.annotations.ApiModelProperty(value ="The version identifier of the \"boot\" component of the currently-installed array firmware." , required = true)
	@XmlElement(required = true)
	private String bootVersion;

	/** @return The version identifier of the "boot" component of the currently-installed array firmware. */
	public String getBootVersion() {
		return this.bootVersion;
	}
	/** @param x The version identifier of the "boot" component of the currently-installed array firmware. */
	public void setBootVersion(String x) {
		this.bootVersion = x;
	}

	/** An ASCII string that describes the currently-installed NVSRAM contents. */
	@io.swagger.annotations.ApiModelProperty(value ="An ASCII string that describes the currently-installed NVSRAM contents." , required = true)
	@XmlElement(required = true)
	private String nvsramVersion;

	/** @return An ASCII string that describes the currently-installed NVSRAM contents. */
	public String getNvsramVersion() {
		return this.nvsramVersion;
	}
	/** @param x An ASCII string that describes the currently-installed NVSRAM contents. */
	public void setNvsramVersion(String x) {
		this.nvsramVersion = x;
	}

	/** An ASCII string that describes the firmware prefix. */
	@io.swagger.annotations.ApiModelProperty(value ="An ASCII string that describes the firmware prefix." , required = true)
	@XmlElement(required = true)
	private String fwPrefix;

	/** @return An ASCII string that describes the firmware prefix. */
	public String getFwPrefix() {
		return this.fwPrefix;
	}
	/** @param x An ASCII string that describes the firmware prefix. */
	public void setFwPrefix(String x) {
		this.fwPrefix = x;
	}

	/** An ASCII string that describes the chassis serial number. */
	@io.swagger.annotations.ApiModelProperty(value ="An ASCII string that describes the chassis serial number." , required = true)
	@XmlElement(required = true)
	private String chassisSerialNumber;

	/** @return An ASCII string that describes the chassis serial number. */
	public String getChassisSerialNumber() {
		return this.chassisSerialNumber;
	}
	/** @param x An ASCII string that describes the chassis serial number. */
	public void setChassisSerialNumber(String x) {
		this.chassisSerialNumber = x;
	}

	/** An ASCII string that identifies the version of the MEL event configuration data. This is used for the event logging enhancements in Chessie 2. */
	@io.swagger.annotations.ApiModelProperty(value ="An ASCII string that identifies the version of the MEL event configuration data. This is used for the event logging enhancements in Chessie 2." , required = true)
	@XmlElement(required = true)
	private String eventConfigurationDataVersion;

	/** @return An ASCII string that identifies the version of the MEL event configuration data. This is used for the event logging enhancements in Chessie 2. */
	public String getEventConfigurationDataVersion() {
		return this.eventConfigurationDataVersion;
	}
	/** @param x An ASCII string that identifies the version of the MEL event configuration data. This is used for the event logging enhancements in Chessie 2. */
	public void setEventConfigurationDataVersion(String x) {
		this.eventConfigurationDataVersion = x;
	}

	/** SAAttributeID attribute-value pairs. */
	@io.swagger.annotations.ApiModelProperty(value ="SAAttributeID attribute-value pairs." , required = true)
	@XmlElement(required = true)
	private int[] arrayAttributes;

	/** @return SAAttributeID attribute-value pairs. */
	public int[] getArrayAttributes() {
		return this.arrayAttributes;
	}
	/** @param x SAAttributeID attribute-value pairs. */
	public void setArrayAttributes(int[] x) {
		this.arrayAttributes = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private int[] res4;

	/** @return Reserved for future use. */
	public int[] getRes4() {
		return this.res4;
	}
	/** @param x Reserved for future use. */
	public void setRes4(int[] x) {
		this.res4 = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private int[] res5;

	/** @return Reserved for future use. */
	public int[] getRes5() {
		return this.res5;
	}
	/** @param x Reserved for future use. */
	public void setRes5(int[] x) {
		this.res5 = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private int[] res6;

	/** @return Reserved for future use. */
	public int[] getRes6() {
		return this.res6;
	}
	/** @param x Reserved for future use. */
	public void setRes6(int[] x) {
		this.res6 = x;
	}

	/** Reserved for future use. */
	@XmlTransient
	private String res7;

	/** @return Reserved for future use. */
	public String getRes7() {
		return this.res7;
	}
	/** @param x Reserved for future use. */
	public void setRes7(String x) {
		this.res7 = x;
	}

	/** This element allows additional content to be added to SAData with actually adding any new elements to the struct. The element replaces a reserved field that was of variable length. */
	@io.swagger.annotations.ApiModelProperty(value ="This element allows additional content to be added to SAData with actually adding any new elements to the struct. The element replaces a reserved field that was of variable length." , required = true)
	@XmlElement(required = true)
	private ExtendedSAData extendedSAData;

	/** @return This element allows additional content to be added to SAData with actually adding any new elements to the struct. The element replaces a reserved field that was of variable length. */
	public ExtendedSAData getExtendedSAData() {
		return this.extendedSAData;
	}
	/** @param x This element allows additional content to be added to SAData with actually adding any new elements to the struct. The element replaces a reserved field that was of variable length. */
	public void setExtendedSAData(ExtendedSAData x) {
		this.extendedSAData = x;
	}
}
