package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This enumeration object is used to specify one of a set of volume actions that may be active for a volume. These volume actions represent "long-running" operations on a volume. Any time such an operation is active, the current progress can be determined using the getVolumeActionProgress procedure. */
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(182)
public enum VolumeAction implements Serializable {
		/** No long-running operations are currently in progress. */
		none(1),
		/** A hot-spare copyback operation is currently in progress. This action will occur after replacement of a failed drive that had been temporarily covered by a hot spare. */
		copyback(2),
		/** Volume initialization is currently in progress. */
		initializing(3),
		/** The volume's data is currently being reconstructed onto either a replaced drive or a hot-spare that will temporarily cover for a failed drive. */
		reconstructing(4),
		/** A volume remap operation is currently in progress. A DCE operation is occurring. */
		remappingDce(5),
		/** A volume remap operation is currently in progress. A DRM operation is occurring. */
		remappingDrm(6),
		/** A volume remap operation is currently in progress. A DCE/DRM operation is occurring. */
		remappingDcedrm(7),
		/** A volume remap operation is currently in progress. A DSEG operation is occurring. */
		remappingDseg(8),
		/** A volume remap operation is currently in progress. A DVE operation is occurring. */
		remappingDve(9),
		/** A volume remap operation is currently in progress. A DCE/DVE operation is occurring. */
		remappingDcedve(10),
		/** A volume movement triggered internally (due to a DVE on another volume). */
		remappingInternal(11),
		/** A defragmentation eliminating free extents (gaps) is taking place. */
		remappingDefrag(12),
		/** A volume format (i.e. write zeros) operation is in progress. */
		formatting(13),
		/** The volume is synchronizing. */
		synchronizing(14),
		/** A volume parity scan is currently in progress. */
		parityScan(17),
		/** A volume copy is currently in progress. */
		volumeCopy(18),
		/** A snapshot rollback is currently in progress. */
		snapshotRollback(19),
		/** A PiT rollback operation is currently in progress. */
		pitRollback(20),
		/** The initial synchronization for an async mirror volume is currently in progress. */
		asyncMirrorGroupInitialSync(21),
		/** Reported when DDP volumes are Critical. */
		reconstructingCritical(22),
		/** A volume rebalancing operation is currently in progress. */
		rebalancing(23),
		/** A copyThenFail operation is evacuating data from a VolumeGroup. */
		copyThenFail(24),
		/** A copyThenFail operation is waiting to start on a VolumeGroup. */
		copyThenFailPending(25),
		/** A copyThenReplace operation is evacuating data from a VolumeGroup. */
		copyThenReplace(26),
		/** A copyThenReplace, followed by failing the drive, is evacuating data from a VolumeGroup. */
		copyThenReplaceAndFail(27),
		/** Volume Defrag is in progress */
		thinDefrag(28),
		/** Reported when a DDP volume is being created as a background operation */
		creating(33),
		/** Reported when a DDP volume is being deleted as a background operation */
		deleting(34),
		__UNDEFINED(464378545);

		public final int value;

		private VolumeAction(int v) {
			this.value = v;
		}
}
