package devmgr.api.symbol;

import devmgr.api.runtime.*;
import java.io.Serializable;
import javax.xml.bind.annotation.*;

/** This structure is used as the argument to the createVolume procedure. It specifies the key attributes of the volume that is to be created, and also indicates the volume candidate that provides the basis for creation of the new volume. */
@SuppressWarnings("serial")
@XmlRootElement
@io.swagger.annotations.ApiModel()
@TypeTableIndex(980)
public class VolumeCreationDescriptor implements Serializable {
	public VolumeCreationDescriptor() {
	}

	/** The volume candidate object that is to be used as the basis for the new volume. */
	@io.swagger.annotations.ApiModelProperty(value ="The volume candidate object that is to be used as the basis for the new volume." , required = true)
	@XmlElement(required = true)
	private VolumeCandidate candidate;

	/** @return The volume candidate object that is to be used as the basis for the new volume. */
	public VolumeCandidate getCandidate() {
		return this.candidate;
	}
	/** @param x The volume candidate object that is to be used as the basis for the new volume. */
	public void setCandidate(VolumeCandidate x) {
		this.candidate = x;
	}

	/** The user-assigned label to be used as the name of the new volume. */
	@io.swagger.annotations.ApiModelProperty(value ="The user-assigned label to be used as the name of the new volume." , required = true)
	@XmlElement(required = true)
	private String label;

	/** @return The user-assigned label to be used as the name of the new volume. */
	public String getLabel() {
		return this.label;
	}
	/** @param x The user-assigned label to be used as the name of the new volume. */
	public void setLabel(String x) {
		this.label = x;
	}

	/** The controller reference value of the controller that will be assigned as the owner of the newly-created volume. */
	@io.swagger.annotations.ApiModelProperty(value ="The controller reference value of the controller that will be assigned as the owner of the newly-created volume." , required = true)
	@XmlElement(required = true)
	private String manager;

	/** @return The controller reference value of the controller that will be assigned as the owner of the newly-created volume. */
	public String getManager() {
		return this.manager;
	}
	/** @param x The controller reference value of the controller that will be assigned as the owner of the newly-created volume. */
	public void setManager(String x) {
		this.manager = x;
	}

	/** The desired capacity of the new volume. Note that the controller may be forced to make the actual volume slightly larger than the requested size to account for arrangement of parity data, etc. If the resulting size is still smaller than the size of the volume candidate, then a new free extent will be created in addition to the new volume to account for the unused capacity. */
	@io.swagger.annotations.ApiModelProperty(value ="The desired capacity of the new volume. Note that the controller may be forced to make the actual volume slightly larger than the requested size to account for arrangement of parity data, etc. If the resulting size is still smaller than the size of the volume candidate, then a new free extent will be created in addition to the new volume to account for the unused capacity." , required = true)
	@XmlElement(required = true)
	private long capacity;

	/** @return The desired capacity of the new volume. Note that the controller may be forced to make the actual volume slightly larger than the requested size to account for arrangement of parity data, etc. If the resulting size is still smaller than the size of the volume candidate, then a new free extent will be created in addition to the new volume to account for the unused capacity. */
	public long getCapacity() {
		return this.capacity;
	}
	/** @param x The desired capacity of the new volume. Note that the controller may be forced to make the actual volume slightly larger than the requested size to account for arrangement of parity data, etc. If the resulting size is still smaller than the size of the volume candidate, then a new free extent will be created in addition to the new volume to account for the unused capacity. */
	public void setCapacity(long x) {
		this.capacity = x;
	}

	/** The desired segment size for the new volume in bytes. This must be one of the supported segment sizes, as specified in the FeatureParameters object returned by the controller. Alternatively, a value of zero can be specified to indicate that the controller should select a reasonable segment size based on the usage hint provided in the volume creation request. */
	@io.swagger.annotations.ApiModelProperty(value ="The desired segment size for the new volume in bytes. This must be one of the supported segment sizes, as specified in the FeatureParameters object returned by the controller. Alternatively, a value of zero can be specified to indicate that the controller should select a reasonable segment size based on the usage hint provided in the volume creation request." , required = true)
	@XmlElement(required = true)
	private int segmentSize;

	/** @return The desired segment size for the new volume in bytes. This must be one of the supported segment sizes, as specified in the FeatureParameters object returned by the controller. Alternatively, a value of zero can be specified to indicate that the controller should select a reasonable segment size based on the usage hint provided in the volume creation request. */
	public int getSegmentSize() {
		return this.segmentSize;
	}
	/** @param x The desired segment size for the new volume in bytes. This must be one of the supported segment sizes, as specified in the FeatureParameters object returned by the controller. Alternatively, a value of zero can be specified to indicate that the controller should select a reasonable segment size based on the usage hint provided in the volume creation request. */
	public void setSegmentSize(int x) {
		this.segmentSize = x;
	}

	/** A true (non-zero) / false (zero) indicator of whether or not automatic cache read-ahead is enabled. */
	@io.swagger.annotations.ApiModelProperty(value ="A true (non-zero) / false (zero) indicator of whether or not automatic cache read-ahead is enabled." , required = true)
	@XmlElement(required = true)
	private int readAhead;

	/** @return A true (non-zero) / false (zero) indicator of whether or not automatic cache read-ahead is enabled. */
	public int getReadAhead() {
		return this.readAhead;
	}
	/** @param x A true (non-zero) / false (zero) indicator of whether or not automatic cache read-ahead is enabled. */
	public void setReadAhead(int x) {
		this.readAhead = x;
	}

	/** A true value is an indication that the client wants the controller to initialize the new volume with all zeros. If this option is selected, the volume will be created and immediately transitioned to the formatting state. This operation can take an extended period of time to complete, and the volume will not be available during the process. A false value indicates that no zeroing is required; the volume will become available immediately, although a background initialization process will be running at the same time. */
	@io.swagger.annotations.ApiModelProperty(value ="A true value is an indication that the client wants the controller to initialize the new volume with all zeros. If this option is selected, the volume will be created and immediately transitioned to the formatting state. This operation can take an extended period of time to complete, and the volume will not be available during the process. A false value indicates that no zeroing is required; the volume will become available immediately, although a background initialization process will be running at the same time." , required = true)
	@XmlElement(required = true)
	private boolean writeZeros;

	/** @return A true value is an indication that the client wants the controller to initialize the new volume with all zeros. If this option is selected, the volume will be created and immediately transitioned to the formatting state. This operation can take an extended period of time to complete, and the volume will not be available during the process. A false value indicates that no zeroing is required; the volume will become available immediately, although a background initialization process will be running at the same time. */
	public boolean isWriteZeros() {
		return this.writeZeros;
	}
	/** @param x A true value is an indication that the client wants the controller to initialize the new volume with all zeros. If this option is selected, the volume will be created and immediately transitioned to the formatting state. This operation can take an extended period of time to complete, and the volume will not be available during the process. A false value indicates that no zeroing is required; the volume will become available immediately, although a background initialization process will be running at the same time. */
	public void setWriteZeros(boolean x) {
		this.writeZeros = x;
	}

	/** A true value indicates that the volume should not have a LUN mapping automatically created for it. Rather, a subsequent Storage Partitions operation will be required to establish such a mapping and allow host I/O accesses to be conveyed to the new volume. A false value indicates that a default mapping should be created for the new volume. */
	@io.swagger.annotations.ApiModelProperty(value ="A true value indicates that the volume should not have a LUN mapping automatically created for it. Rather, a subsequent Storage Partitions operation will be required to establish such a mapping and allow host I/O accesses to be conveyed to the new volume. A false value indicates that a default mapping should be created for the new volume." , required = true)
	@XmlElement(required = true)
	private boolean noMapping;

	/** @return A true value indicates that the volume should not have a LUN mapping automatically created for it. Rather, a subsequent Storage Partitions operation will be required to establish such a mapping and allow host I/O accesses to be conveyed to the new volume. A false value indicates that a default mapping should be created for the new volume. */
	public boolean isNoMapping() {
		return this.noMapping;
	}
	/** @param x A true value indicates that the volume should not have a LUN mapping automatically created for it. Rather, a subsequent Storage Partitions operation will be required to establish such a mapping and allow host I/O accesses to be conveyed to the new volume. A false value indicates that a default mapping should be created for the new volume. */
	public void setNoMapping(boolean x) {
		this.noMapping = x;
	}

	/** The label to assign to the new volume group, if any. This field is only used when the candidate selection type is CANDIDATE_SEL_MANUAL or CANDIDATE_SEL_COUNT. */
	@io.swagger.annotations.ApiModelProperty(value ="The label to assign to the new volume group, if any. This field is only used when the candidate selection type is CANDIDATE_SEL_MANUAL or CANDIDATE_SEL_COUNT." , required = true)
	@XmlElement(required = true)
	private String volumeGroupLabel;

	/** @return The label to assign to the new volume group, if any. This field is only used when the candidate selection type is CANDIDATE_SEL_MANUAL or CANDIDATE_SEL_COUNT. */
	public String getVolumeGroupLabel() {
		return this.volumeGroupLabel;
	}
	/** @param x The label to assign to the new volume group, if any. This field is only used when the candidate selection type is CANDIDATE_SEL_MANUAL or CANDIDATE_SEL_COUNT. */
	public void setVolumeGroupLabel(String x) {
		this.volumeGroupLabel = x;
	}

	/** This field specifies which protection type should be used for the volume being created. */
	@io.swagger.annotations.ApiModelProperty(value ="This field specifies which protection type should be used for the volume being created." , required = true)
	@XmlElement(required = true)
	private ProtectionType protectionType = ProtectionType.__UNDEFINED;

	/** @return This field specifies which protection type should be used for the volume being created. */
	public ProtectionType getProtectionType() {
		return this.protectionType;
	}
	/** @param x This field specifies which protection type should be used for the volume being created. */
	public void setProtectionType(ProtectionType x) {
		this.protectionType = x;
	}
}
